@@ -668,8 +668,8 @@ private:
 
     
     void reallocateStringBuf();
-    Chain getPlanString(Element *pPlan, const Chain& title, int indent = 0);
-    Chain getJoinPlanString(Element *pJoin, const Chain& title, int indent = 0);
+    Chain getPlanString(Element *pPlan, const Chain& title, unsigned indent = 0);
+    Chain getJoinPlanString(Element *pJoin, const Chain& title, unsigned indent = 0);
 
     void formatTableInfo(const Chain& tableSet, const Chain& tableName, 
 			 const ListT<CegoTableObject>& idxList,
@@ -684,13 +684,13 @@ private:
 
     char *_pC;
 
-    int _stringBufLen;
+    unsigned _stringBufLen;
     char *_stringBuf; // [MAXSTRINGLEN];
 
     Chain _fieldName;
     CegoDataType _dataType;
-    int _dataLen;
-    int _dataDim;
+    unsigned _dataLen;
+    unsigned _dataDim;
 
     CegoDistManager* _pTabMng;
     
@@ -742,7 +742,7 @@ private:
     StackT<ListT<CegoProcBlock*>* > _ifBlockListStack;
     StackT<CegoComparison> _compStack;
     StackT<bool> _distinctStack;
-    StackT<int> _limitStack;
+    StackT<unsigned> _limitStack;
 
     CegoOrderNode::Ordering _orderingOpt;
     
@@ -787,8 +787,8 @@ private:
     Chain _procTableSet;
     
     CegoDataType _returnType;
-    int _returnTypeLen;
-    int _returnTypeDim;
+    unsigned _returnTypeLen;
+    unsigned _returnTypeDim;
     
     CegoProcedure::ProcType _procType;
       
