@@ -37,7 +37,7 @@ class CegoAdmNet {
     CegoAdmNet(const Chain& logFile, const Chain& progName, const Chain& logMode );
     ~CegoAdmNet();
     
-    void connect(const Chain& serverName, int port, const Chain& user, const Chain& pwd);
+    void connect(const Chain& serverName, unsigned port, const Chain& user, const Chain& pwd);
 
     void getTableSetList(ListT<Chain>& tslist);
     void getTableSetInfo(const Chain& tableSet, 
@@ -57,19 +57,19 @@ class CegoAdmNet {
     void importTableSet(const Chain& tableSet, const Chain& impMode, const Chain& impFile);
     void exportTableSet(const Chain& tableSet, const Chain& expMode, const Chain& expFile);
 
-    void addDataFile(const Chain& tableSet, const Chain& fileType, const Chain& dataFile, int numPages);
+    void addDataFile(const Chain& tableSet, const Chain& fileType, const Chain& dataFile, unsigned numPages);
     
     void defineTableSet(const Chain& tableSet, 
 			const Chain& tsRoot,
 			const Chain& primary,
 			const Chain& secondary,
-			int sysSize,
-			int tmpSize,
-			int appSize,
-			int logSize,
-			int logNum, 
+			unsigned sysSize,
+			unsigned tmpSize,
+			unsigned appSize,
+			unsigned logSize,
+			unsigned logNum, 
 			unsigned long long orderSize,
-			int branchId);
+			unsigned branchId);
     
     void createTableSet(const Chain& tableSet);
     void dropTableSet(const Chain& tableSet);
