@@ -209,13 +209,13 @@ public:
     ResultType reqPoolEntryList();
     ResultType reqThreadInfo();
     ResultType reqDbThreadInfo();
-    ResultType reqDbThreadHistory(int threadId);
+    ResultType reqDbThreadHistory(unsigned threadId);
 
-    ResultType reqQueryHistoryLast(int numLast);
-    ResultType reqQueryHistoryCost(int numLast);
+    ResultType reqQueryHistoryLast(unsigned numLast);
+    ResultType reqQueryHistoryCost(unsigned numLast);
 
-    ResultType reqNumQueryLast(int numLast);
-    ResultType reqNumQueryCost(int numCost);
+    ResultType reqNumQueryLast(unsigned numLast);
+    ResultType reqNumQueryCost(unsigned numCost);
     
     ResultType reqAdmThreadInfo();
     ResultType reqLogThreadInfo();
@@ -225,23 +225,24 @@ public:
     ResultType reqShowQueryCache(const Chain& tableSet);
     ResultType reqListQueryCache(const Chain& tableSet);
     ResultType reqCleanQueryCache(const Chain& tableSet);
-    ResultType reqSetQueryCacheParam(const Chain& tableSet, int maxEntry, int maxSize, int threshold, int hashRange);
+    ResultType reqSetQueryCacheParam(const Chain& tableSet, unsigned maxEntry, unsigned maxSize, unsigned threshold, unsigned hashRange);
 
     ResultType reqShowTableCache(const Chain& tableSet);
     ResultType reqListTableCache(const Chain& tableSet);
     ResultType reqCleanTableCache(const Chain& tableSet);
 
-    ResultType reqSetTableCacheParam(const Chain& tableSet, const Chain& cacheFilter, int maxEntry, int maxSize, int hashRange);
+    ResultType reqSetTableCacheParam(const Chain& tableSet, const Chain& cacheFilter, unsigned maxEntry,
+				     unsigned maxSize, unsigned hashRange);
         
-    ResultType reqDbThreadAbort(int threadId);
+    ResultType reqDbThreadAbort(unsigned threadId);
     
     ResultType reqDefineTableSet(const Chain& tableSet, 
 				 const Chain& tsRoot,
 				 const Chain& primary,
 				 const Chain& secondary, 
 				 const Chain& mediator,
-				 int sysFileId, int tempFileId, int sysFileSize, int tempFileSize, int appFileSize,
-				 int logFileSize, int logFileNum, unsigned long long sortAreaSize);
+				 unsigned sysFileId, unsigned tempFileId, unsigned sysFileSize, unsigned tempFileSize, unsigned appFileSize,
+				 unsigned logFileSize, unsigned logFileNum, unsigned long long sortAreaSize);
     ResultType reqRemoveTableSet(const Chain& tableSet);
     ResultType reqResetTableSet(const Chain& tableSet);
     ResultType reqCreateTableSet(const Chain& tableSet);
@@ -253,14 +254,14 @@ public:
 
     ResultType reqInitLogs(const Chain& tableSet);
 
-    ResultType reqSyncTableSet(const Chain& tableSet, const Chain& msg, const Chain& escCmd, int timeout);
+    ResultType reqSyncTableSet(const Chain& tableSet, const Chain& msg, const Chain& escCmd, unsigned timeout);
 
     ResultType reqGetDbSpec(Chain& dbSpec);
     ResultType reqCopyTableSet(const Chain& tableSet, const Chain& secondary, const Chain& mediator);
     ResultType reqStartRecovery(const Chain& tableSet);
     ResultType reqStopRecovery(const Chain& tableSet);
 
-    ResultType reqCopyFile(const Chain& fileName, int copyId = 0);
+    ResultType reqCopyFile(const Chain& fileName, unsigned copyId = 0);
 
     ResultType reqGetNodeList();
     ResultType reqGetDbInfo();
@@ -279,7 +280,7 @@ public:
     ResultType reqSetRunState(const Chain& tableSet, const Chain& runState);
     ResultType reqSetSyncState(const Chain& tableSet, const Chain& syncState);
 
-    ResultType reqRegisterHost(const Chain& hostName, const int dataPortNo, const int adminPortNo );
+    ResultType reqRegisterHost(const Chain& hostName, const unsigned dataPortNo, const unsigned adminPortNo );
 
     ResultType reqExportTableSet(const Chain& tableSet, bool isStructure, const Chain& exportFile, const Chain& expMode);
     ResultType reqImportTableSet(const Chain& tableSet, bool isStructure, const Chain& importFile, const Chain& impMode);
@@ -287,7 +288,7 @@ public:
     ResultType reqExportTable(const Chain& tableSet, const Chain& tableName, const Chain& exportFile, const Chain& expMode);
     ResultType reqImportTable(const Chain& tableSet, const Chain& tableName, const Chain& importFile, const Chain& impMode);
 
-    ResultType reqAddDataFile(const Chain& tableSet, const Chain& fileType, int fileId, const Chain& dataFile, int fileSize);
+    ResultType reqAddDataFile(const Chain& tableSet, const Chain& fileType, unsigned fileId, const Chain& dataFile, unsigned fileSize);
     
     ResultType reqShowUser();
     ResultType reqAddUser(const Chain& user, const Chain& password);
@@ -320,21 +321,21 @@ public:
 
     ResultType reqDumpObject(const Chain& tableSet, CegoObject::ObjectType type, const Chain& objName);
 
-    ResultType reqSetLogMng(const Chain& progName, int timeout);
+    ResultType reqSetLogMng(const Chain& progName, unsigned timeout);
     ResultType reqSetBackupMng(const Chain& progName);
     ResultType reqShowLogMng();
     ResultType reqShowBackupMng();
 
-    ResultType reqSetCheckpoint(const Chain& tableSet, int interval);
+    ResultType reqSetCheckpoint(const Chain& tableSet, unsigned interval);
     ResultType reqSetTSInitFile(const Chain& tableSet, const Chain& initFile);
 
-    ResultType reqSetTSSysSize(const Chain& tableSet, int sysSize);
-    ResultType reqSetTSTmpSize(const Chain& tableSet, int tmpSize);
-    ResultType reqSetTSAppSize(const Chain& tableSet, int appSize);
+    ResultType reqSetTSSysSize(const Chain& tableSet, unsigned sysSize);
+    ResultType reqSetTSTmpSize(const Chain& tableSet, unsigned tmpSize);
+    ResultType reqSetTSAppSize(const Chain& tableSet, unsigned appSize);
     ResultType reqSetTSRootPath(const Chain& tableSet, const Chain& tsRoot);
 
-    ResultType reqSetTSLogNum(const Chain& tableSet, int logNum);
-    ResultType reqSetTSLogSize(const Chain& tableSet, int logSize);
+    ResultType reqSetTSLogNum(const Chain& tableSet, unsigned logNum);
+    ResultType reqSetTSLogSize(const Chain& tableSet, unsigned logSize);
     ResultType reqSetTSSortAreaSize(const Chain& tableSet, unsigned long long sortAreaSize);
     ResultType reqSetTSLogUser(const Chain& tableSet, const Chain& logUser);
 
@@ -357,10 +358,10 @@ public:
 				 const Chain& tsRoot,
 				 const Chain& primary,
 				 const Chain& secondary,
-				 int sysFileSize, int tmpFileSize, int appFileSize,
-				 int logFileSize, int logFileNum,
+				 unsigned sysFileSize, unsigned tmpFileSize, unsigned appFileSize,
+				 unsigned logFileSize, unsigned logFileNum,
 				 unsigned long long sortAreaSize,
-				 int branchId);
+				 unsigned branchId);
     
     ResultType medDropTableSet(const Chain& tableSet);
     ResultType medRemoveTableSet(const Chain& tableSet);
@@ -369,7 +370,7 @@ public:
     ResultType medCopyTableSet(const Chain& tableSet);
     ResultType medSwitchTableSet(const Chain& tableSet);
 
-    ResultType medAddDataFile(const Chain& tableSet, const Chain& fileType, const Chain& dataFile, int fileSize);
+    ResultType medAddDataFile(const Chain& tableSet, const Chain& fileType, const Chain& dataFile, unsigned fileSize);
     ResultType medAddArchLog(const Chain& tableSet, const Chain& archId, const Chain& archPath);
     ResultType medRemoveArchLog(const Chain& tableSet, const Chain& archId);
     ResultType medGetTableSetList(bool getUsage = false);
@@ -481,11 +482,11 @@ public:
     void getTableSetRoot(Chain& tsRoot);
     void getTableSetTSTicket(Chain& tsTicket);
     void getTableName(Chain& tableName);
-    void getThreadId(int& threadId);
-    void getFileId(int& fileId);
+    void getThreadId(unsigned& threadId);
+    void getFileId(unsigned& fileId);
     void getFileName(Chain& fileName);
     void getFileType(Chain& fileType);
-    void getFileSize(int& fileSize);
+    void getFileSize(unsigned& fileSize);
     void getFilter(Chain& filter);
     void getTargetHost(Chain& targetHost);
     void getEscapeCmd(Chain& escCmd);
@@ -494,11 +495,11 @@ public:
     void getTSLogUser(Chain& logUser);
 	
     void getTSTicket(Chain& tsRoot);
-    void getTSLogNum(int& logNum);
-    void getTSLogSize(int& logSize);
+    void getTSLogNum(unsigned& logNum);
+    void getTSLogSize(unsigned& logSize);
     void getTSSortAreaSize(unsigned long long& sortAreaSize);
 
-    void getTimeoutValue(int& timeout);
+    void getTimeoutValue(unsigned& timeout);
     void getUser(Chain& user);
     void getPassword(Chain& passwd);
     void getPerm(Chain& perm);
@@ -509,7 +510,7 @@ public:
     void getUsage(bool& getUsage);
 
     void getLogManager(Chain& progName);
-    void getLogManagerTimeout(int& timeout);
+    void getLogManagerTimeout(unsigned& timeout);
 
     void getBackupManager(Chain& progName);
     
@@ -517,22 +518,22 @@ public:
     void getPrimary(Chain& primary);
     void getSecondary(Chain& secondary);
     void getMediator(Chain& mediator);
-    void getSysFileId(int& sysFid);
-    void getTmpFileId(int& tmpFid);
-    void getSysSize(int& sysSize);
-    void getTmpSize(int& tmpSize);
-    void getAppSize(int& appSize);
-    void getLogFileSize(int& logFileSize);
-    void getLogFileNum(int& logFileNum);
+    void getSysFileId(unsigned& sysFid);
+    void getTmpFileId(unsigned& tmpFid);
+    void getSysSize(unsigned& sysSize);
+    void getTmpSize(unsigned& tmpSize);
+    void getAppSize(unsigned& appSize);
+    void getLogFileSize(unsigned& logFileSize);
+    void getLogFileNum(unsigned& logFileNum);
     void getSortAreaSize(unsigned long long& sortAreaSize);
-    void getBranchId(int& branchId);
+    void getBranchId(unsigned& branchId);
     void getArchId(Chain& archId);
     void getArchPath(Chain& archPath);
     void getHostRole(Chain& hostRole);
     void getHostName(Chain& hostName);
     void getHostStatus(Chain& hostStatus);
-    void getDataPort(int& dataPort);
-    void getAdminPort(int& adminPort);
+    void getDataPort(unsigned& dataPort);
+    void getAdminPort(unsigned& adminPort);
     void getDataId(Chain& dataId);
     void getLSN(unsigned long long& lsn);
     void getRunState(Chain& runState);
@@ -551,17 +552,17 @@ public:
     void getObjType(CegoObject::ObjectType& type);
 
     void getTableCacheFilter(Chain& cacheFilter);
-    void getTableCacheMaxSize(int& maxSize);
-    void getTableCacheMaxEntry(int& maxEntry);
-    void getTableCacheHashRange(int& hashRange);
+    void getTableCacheMaxSize(unsigned& maxSize);
+    void getTableCacheMaxEntry(unsigned& maxEntry);
+    void getTableCacheHashRange(unsigned& hashRange);
     
-    void getQueryCacheMaxEntry(int& maxEntry);
-    void getQueryCacheMaxSize(int& maxSize);
-    void getQueryCacheThreshold(int& threshold);
-    void getQueryCacheHashRange(int& hashRange);
+    void getQueryCacheMaxEntry(unsigned& maxEntry);
+    void getQueryCacheMaxSize(unsigned& maxSize);
+    void getQueryCacheThreshold(unsigned& threshold);
+    void getQueryCacheHashRange(unsigned& hashRange);
 
-    void getNumLast(int& numLast);
-    void getNumCost(int& numCost);
+    void getNumLast(unsigned& numLast);
+    void getNumCost(unsigned& numCost);
     
 private:
 
