@@ -32,7 +32,7 @@ CegoBTreeCursor::CegoBTreeCursor()
 {
 }
 
-CegoBTreeCursor::CegoBTreeCursor(CegoTableManager *pTabMng, int tabSetId, const Chain& btreeName, CegoObject::ObjectType type, CegoAttrCond* pAttrCond, bool ignoreTouched, bool readUncommitted)
+CegoBTreeCursor::CegoBTreeCursor(CegoTableManager *pTabMng, unsigned tabSetId, const Chain& btreeName, CegoObject::ObjectType type, CegoAttrCond* pAttrCond, bool ignoreTouched, bool readUncommitted)
 {
     _pTabMng = pTabMng;
     _pDBMng = pTabMng->getDBMng();
@@ -145,15 +145,15 @@ bool CegoBTreeCursor::getFirst(ListT<CegoField>& fl, CegoDataPointer& dp)
 		    while ( goOn )
 		    {
 			CegoBTreeValue iv;
-			int numEntries = _curLeaf.numEntries();
+			unsigned numEntries = _curLeaf.numEntries();
 					
 			if ( numEntries > 0 )
 			{
 			    // cout << "Detected " << numEntries << " entries" << endl; 
-			    int u = numEntries;
-			    int d = 0;
+			    unsigned u = numEntries;
+			    unsigned d = 0;
 
-			    int pos = 0;
+			    unsigned pos = 0;
 			    
 			    while ( u > d + 1 )
 			    {
@@ -254,9 +254,9 @@ bool CegoBTreeCursor::getFirst(ListT<CegoField>& fl, CegoDataPointer& dp)
 		       where the mean value is calculated and checked
 		    */
 			
-		    int lb = 0;
-		    int rb = traceNode.numEntries();
-		    int pos;
+		    unsigned lb = 0;
+		    unsigned rb = traceNode.numEntries();
+		    unsigned pos;
 		    
 		    bool goOn = true;
 		    
@@ -348,17 +348,17 @@ bool CegoBTreeCursor::getFirst(ListT<CegoField>& fl, CegoDataPointer& dp)
 		    while ( goOn )
 		    {			
 			CegoBTreeValue iv;
-		        int numEntries = _curLeaf.numEntries();
+		        unsigned numEntries = _curLeaf.numEntries();
 
 			// cout << "Starting leaf trace .." << endl;
 			
 			if ( numEntries > 0 )
 			{
 			    // cout << "Detected " << numEntries << " entries" << endl; 
-			    int u = numEntries;
-			    int d = 0;
+			    unsigned u = numEntries;
+			    unsigned d = 0;
 
-			    int pos = 0;
+			    unsigned pos = 0;
 			    
 			    while ( u > d + 1 )
 			    {
@@ -485,7 +485,7 @@ bool CegoBTreeCursor::getFirst(ListT<CegoField>& fl, CegoDataPointer& dp)
     if ( found )
     {	
 	char* p;
-	int len;
+	unsigned len;
 
 	// optimized way, we could save some unfix/fix operations
 	_pTabMng->releaseAndClaimDataPtrUnlocked(_dataPtr, false, _tabSetId, CegoBufferPool::SYNC, dp, p, len, _dataPtr);
@@ -496,10 +496,10 @@ bool CegoBTreeCursor::getFirst(ListT<CegoField>& fl, CegoDataPointer& dp)
 	unsigned long long tastep;
 	CegoTupleState ts;
 
-	int toff = _qh.decodeTupleHeader(tid, tastep, ts, p);
+	unsigned toff = _qh.decodeTupleHeader(tid, tastep, ts, p);
 
 	char* tp = p + toff;
-	int tlen = len - toff;
+	unsigned tlen = len - toff;
 
 	if ( tid != 0 )
 	{
@@ -639,7 +639,7 @@ bool CegoBTreeCursor::getNext(ListT<CegoField>& fl, CegoDataPointer& dp)
 	if ( attrMatch )
 	{   
 	    char* p;
-	    int len;
+	    unsigned len;
 
 	    // cout << "Releasing pageid " << _dataPtr.getPageId() << " and claiming pageid " << dp.getPageId() << endl;
 	    
@@ -654,12 +654,12 @@ bool CegoBTreeCursor::getNext(ListT<CegoField>& fl, CegoDataPointer& dp)
 	    unsigned long long tastep;
 	    CegoTupleState ts;
 
-	    int toff = _qh.decodeTupleHeader(tid, tastep, ts, p);
+	    unsigned toff = _qh.decodeTupleHeader(tid, tastep, ts, p);
 
 	    char* tp = p + toff;
-	    int tlen = len - toff;
+	    unsigned tlen = len - toff;
 
-	    if (tid != 0)
+	    if ( tid != 0 )
 	    {		    
 		if ( _ignoreTouched )
 		{
@@ -742,7 +742,7 @@ void CegoBTreeCursor::prepareComp()
 {    
     CegoField* pF = _btreeSchema.First();
 
-    int i=0;
+    unsigned i=0;
     while ( pF ) 
     {
 	CegoAttrComp* pAC = _pAttrCond->getAttrCompSet().First();
@@ -751,7 +751,7 @@ void CegoBTreeCursor::prepareComp()
 	{
 	    if  ( (Chain)pAC->getAttrName() == (Chain)pF->getAttrName()  )
 	    {
-		int pos = CegoBTreeValue::getKeyPos(pF->getAttrName(), _btreeSchema);
+		unsigned pos = CegoBTreeValue::getKeyPos(pF->getAttrName(), _btreeSchema);
 
 		if ( i >= TABMNG_MAXBTREECOMP )
 		    throw Exception(EXLOC, "BTree compare array exceeded");
@@ -771,8 +771,8 @@ void CegoBTreeCursor::prepareComp()
 
 CegoBTreeCursor::Direction CegoBTreeCursor::traceLow(const CegoBTreeValue& val)
 {    
-    int i=0;
-    int pos=0;
+    unsigned i=0;
+    unsigned pos=0;
     while ( i < _numComp )
     {	
 	CegoFieldValue fv;
@@ -828,8 +828,8 @@ CegoBTreeCursor::Direction CegoBTreeCursor::traceLow(const CegoBTreeValue& val)
 
 bool CegoBTreeCursor::inRange(const CegoBTreeValue& val)
 {    
-    int i=0;
-    int pos=0;
+    unsigned i=0;
+    unsigned pos=0;
     while ( i < _numComp )
     {	
 	CegoFieldValue fv;
@@ -910,7 +910,7 @@ bool CegoBTreeCursor::inRange(const CegoBTreeValue& val)
 
 bool CegoBTreeCursor::fullMatch(const CegoBTreeValue& val)
 {    
-    for ( int i=0; i < _numComp; i++ ) 
+    for ( unsigned i=0; i < _numComp; i++ ) 
     {
 	// Chain v = _compInfo[i].pAttrComp->getFieldValue().toChain();
 	// _pDBMng->log(_modId, Logger::NOTICE, Chain("compare to ") + v);
@@ -986,7 +986,7 @@ void CegoBTreeCursor::checkRangeAndMatch(const CegoBTreeValue& val, bool& inRang
     inRange=true;
     doMatch=true;
     
-    int i=0;
+    unsigned i=0;
 
     while ( i < _numComp && ( rangeSetup == false || matchSetup == false ) )
     {	
