@@ -37,13 +37,13 @@ CegoBTreeObject::CegoBTreeObject(const CegoBTreeObject& oe) : CegoContentObject(
     _relevance = oe._relevance;
 }
 
-CegoBTreeObject::CegoBTreeObject(int tabSetId, CegoObject::ObjectType type, const Chain& objName ) : CegoContentObject(tabSetId, type, objName)
+CegoBTreeObject::CegoBTreeObject(unsigned tabSetId, CegoObject::ObjectType type, const Chain& objName ) : CegoContentObject(tabSetId, type, objName)
 {
     _pageId = 0;
     _relevance = 0;
 }
 
-CegoBTreeObject::CegoBTreeObject(int tabSetId, CegoObject::ObjectType type,  const Chain& objName, const ListT<CegoField>& schema, const Chain& tabName) : CegoContentObject(tabSetId, type, objName, tabName, schema)
+CegoBTreeObject::CegoBTreeObject(unsigned tabSetId, CegoObject::ObjectType type,  const Chain& objName, const ListT<CegoField>& schema, const Chain& tabName) : CegoContentObject(tabSetId, type, objName, tabName, schema)
 {
     _pageId = 0;
     _relevance=0;
@@ -78,17 +78,17 @@ void CegoBTreeObject::decreaseRelevance()
     _relevance--;
 }
 
-int CegoBTreeObject::getRelevance() const
+unsigned CegoBTreeObject::getRelevance() const
 {
     return _relevance;
 }
 
-int CegoBTreeObject::getEntrySize() const
+unsigned CegoBTreeObject::getEntrySize() const
 {
-    int entrySize = CegoContentObject::getBaseContentSize();
+    unsigned entrySize = CegoContentObject::getBaseContentSize();
 
     entrySize = entrySize + sizeof(PageIdType); // pageId
-    entrySize = entrySize + sizeof(int); // relevance
+    entrySize = entrySize + sizeof(unsigned); // relevance
         
     return entrySize;
 }
@@ -97,7 +97,7 @@ void CegoBTreeObject::encode(char *buf) const
 {
     char* bufPtr = buf;
 
-    int entrySize = getEntrySize();
+    unsigned entrySize = getEntrySize();
 
     CegoContentObject::encodeBaseContent(bufPtr, entrySize);
     bufPtr += CegoContentObject::getBaseContentSize();
@@ -105,15 +105,15 @@ void CegoBTreeObject::encode(char *buf) const
     memcpy(bufPtr, &_pageId, sizeof(PageIdType));
     bufPtr = bufPtr + sizeof(PageIdType);
 
-    memcpy(bufPtr, &_relevance, sizeof(int));
-    bufPtr = bufPtr + sizeof(int);
+    memcpy(bufPtr, &_relevance, sizeof(unsigned));
+    bufPtr = bufPtr + sizeof(unsigned);
 }
 
 void CegoBTreeObject::decode(char *buf)
 {
     char* bufPtr = buf;
 
-    int size;
+    unsigned size;
 
     CegoContentObject::decodeBaseContent(bufPtr, size);
     bufPtr += CegoContentObject::getBaseContentSize();
@@ -121,8 +121,8 @@ void CegoBTreeObject::decode(char *buf)
     memcpy(&_pageId, bufPtr, sizeof(PageIdType));
     bufPtr = bufPtr + sizeof(PageIdType);
 
-    memcpy(&_relevance, bufPtr, sizeof(int));
-    bufPtr = bufPtr + sizeof(int);
+    memcpy(&_relevance, bufPtr, sizeof(unsigned));
+    bufPtr = bufPtr + sizeof(unsigned);
 }
 
 bool CegoBTreeObject::isValid()
@@ -148,7 +148,7 @@ Chain CegoBTreeObject::getId(CegoProcBlock *pBlock) const
     return getTabName() + Chain("@") + getTableSet() + Chain("@") + getName();
 }
 
-Chain CegoBTreeObject::toChain(int defTabSetId) const
+Chain CegoBTreeObject::toChain(unsigned defTabSetId) const
 {
     if  ( defTabSetId == getTabSetId() )
 	return getTabName() + Chain(" ") + getName();
