@@ -35,12 +35,12 @@ class CegoCaseCond {
 public:
 
     CegoCaseCond();
-    CegoCaseCond(char* buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, int tabSetId);
+    CegoCaseCond(char* buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, unsigned tabSetId);
     ~CegoCaseCond();
 
     void cleanUp();    
 
-    void setTabSetId(int tabSetId);
+    void setTabSetId(unsigned tabSetId);
     
     void addPred(CegoPredicate *CegoPredDesc, CegoExpr* pExpr);
     void setElseExpr(CegoExpr *pExpr);
@@ -50,7 +50,7 @@ public:
     CegoExpr* getElseExpr();
 
     ListT<CegoAttrDesc*> getAttrRefList() const;
-    int evalReferences(CegoContentObject *pCO, const ListT<CegoField>& fl);
+    unsigned evalReferences(CegoContentObject *pCO, const ListT<CegoField>& fl);
     ListT<CegoAggregation*> getAggregationList();
     
     void clearAttrCache();
@@ -67,12 +67,12 @@ public:
     void getSelectQueryList(ListT<CegoSelect*>& queryList);
     
     Chain getId(CegoProcBlock *pBlock) const;
-    Chain toChain(int defTabSetId) const;
+    Chain toChain(unsigned defTabSetId) const;
     Chain dbFormat(CegoDatabaseFormater *pForm) const;
     
     void encode(char *buf, CegoProcBlock *pBlock);
-    void decode(char *buf, CegoDistManager* pGTM, CegoProcBlock *pBlock, int tabSetId);
-    int getEncodingLength(CegoProcBlock *pBlock) const;
+    void decode(char *buf, CegoDistManager* pGTM, CegoProcBlock *pBlock, unsigned tabSetId);
+    unsigned getEncodingLength(CegoProcBlock *pBlock) const;
 
     void getPlanList(ListT<Element*>& planList);
 	
