@@ -41,8 +41,8 @@ public:
     CegoDatabaseFormater();
     ~CegoDatabaseFormater();
     
-    virtual Chain formatProcedure(const Chain& procName, CegoProcedure::ProcType procType, CegoDataType returnType, int returnTypeLen, int returnTypeDim, CegoProcBlock* pBlock) = 0;
-    virtual Chain formatProcVar(const Chain& varName, CegoProcVar::VarType varType, CegoDataType dt, int dtlen, int dtdim) = 0; 
+    virtual Chain formatProcedure(const Chain& procName, CegoProcedure::ProcType procType, CegoDataType returnType, unsigned returnTypeLen, unsigned returnTypeDim, CegoProcBlock* pBlock) = 0;
+    virtual Chain formatProcVar(const Chain& varName, CegoProcVar::VarType varType, CegoDataType dt, unsigned dtlen, unsigned dtdim) = 0; 
     virtual Chain formatProcBlock(const ListT<CegoProcVar>& varList, const ListT<CegoProcStmt*>& stmtList,  const ListT<CegoProcException*>& exceptionList) = 0;
     virtual Chain formatProcAssignStmt(CegoProcAssignStmt::AssignmentMode mode, const Chain paramName, CegoExpr* pExpr) = 0;
     virtual Chain formatProcThrowStmt(CegoExpr* pExpr) = 0;
@@ -76,7 +76,7 @@ public:
 			       ListT<CegoAttrDesc*> *pGroupList,
 			       CegoPredicate* pHavingPred,
 			       ListT<CegoExpr*> *pOrderList,
-			       int rowLimit,
+			       unsigned rowLimit,
 			       CegoSelect* pUnionSelect) = 0;
     virtual Chain formatProcFetch(const Chain& curName, const ListT<Chain>& varList) = 0;
     virtual Chain formatPred(CegoPredicate::CompMode mode,
@@ -112,7 +112,7 @@ public:
     virtual Chain formatCaseCond(const ListT<CegoPredicate*>& predList, const ListT<CegoExpr*>& exprList, CegoExpr* elseExpr) = 0;
     virtual Chain formatReturnValue(const Chain& varName, CegoExpr* pExpr) = 0;
     virtual Chain formatAlter(CegoAlterDesc::AlterType type, const CegoField& f, const Chain& attrName) = 0;
-    virtual Chain formatFieldValue(CegoDataType type, void *pV, int len ) = 0;
+    virtual Chain formatFieldValue(CegoDataType type, void *pV, unsigned len ) = 0;
     virtual Chain formatTrigger(const Chain& triggerName,
 				bool isBefore,
 				bool isOnInsert,
