@@ -286,11 +286,14 @@ bool CegoDbHandler::acceptSession()
 	    }
 #endif
 	    _pSer->reset();
-	    Chain req = _pSer->readChain();
+
+	    Chain checkRequest(SER_SESSION);
+	 
+	    Chain req = _pSer->readChain(checkRequest.length()-1);
 
 	    // cout << "READING REQ = " << req << endl;
-
-	    if ( req != Chain(SER_SESSION))
+	    
+	    if ( req != checkRequest)
 	    {
 		_pSer->reset();
 		_pSer->writeChain(Chain(SER_ERROR));
@@ -517,7 +520,7 @@ const ListT<CegoField>& CegoDbHandler::getSchema()
 		{
 		    defValue = CegoFieldValue(dataType, colDefValue);
 		}
-		CegoField f(CegoField(colTable, colTable, colName, dataType, colSize.asInteger(), colDim.asInteger(), defValue, isNullable));	
+		CegoField f(CegoField(colTable, colTable, colName, dataType, colSize.asUnsigned(), colDim.asUnsigned(), defValue, isNullable));	
 		
 		_serSchema.Insert(f);
 		
@@ -671,7 +674,7 @@ CegoDbHandler::ResultType CegoDbHandler::receiveTableData(const ListT<CegoField>
 	    }
 	}
 
-	int col=1;
+	unsigned col=1;
 	CegoField *pF = schema.First();
 	while ( pF ) 
 	{
@@ -1411,7 +1414,7 @@ CegoDbHandler::ResultType CegoDbHandler::getBlob(CegoBlob& blob)
 	    return DB_ERROR;
 	}
 
-	blobSize = _pSer->readChain().asInteger();
+	blobSize = _pSer->readChain().asUnsigned();
     }
 
     blob.allocate(blobSize);
@@ -1701,7 +1704,7 @@ CegoDbHandler::ResultType CegoDbHandler::getClob(CegoClob& clob)
 	{
 	    return DB_ERROR;
 	}
-	clobSize = _pSer->readChain().asInteger();
+	clobSize = _pSer->readChain().asUnsigned();
     }
 
     clob.allocate(clobSize);
@@ -2215,12 +2218,12 @@ CegoDbHandler::RequestType CegoDbHandler::acceptRequest()
 	}
 	else if (  req == Chain(SER_DELETE) ) 
 	{
-	    _serAffected = _pSer->readChain().asInteger();
+	    _serAffected = _pSer->readChain().asUnsigned();
 	    return CegoDbHandler::DELETETABLE;
 	}
 	else if (  req == Chain(SER_UPDATE) ) 
 	{
-	    _serAffected = _pSer->readChain().asInteger();
+	    _serAffected = _pSer->readChain().asUnsigned();
 	    return CegoDbHandler::UPDATE;
 	}
 	else if (  req == Chain(SER_OBJECTINFO) ) 
@@ -2527,7 +2530,7 @@ void CegoDbHandler::collectData(const ListT<CegoField>& schema)
 	
 	Element *pRowElement = new Element(XML_ROW_ELEMENT);
 	
-	int col=1;
+	unsigned col=1;
 	CegoField *pF = schema.First();
 	while ( pF )
 	{	    
@@ -2565,7 +2568,7 @@ void CegoDbHandler::collectData(const ListT<CegoField>& schema, const ListT<Cego
 	
 	Element *pRowElement = new Element(XML_ROW_ELEMENT);
 	
-	int col=1;
+	unsigned col=1;
 	CegoField *pF = schema.First();
 	CegoFieldValue *pFV = fvl.First();
 	
@@ -2592,7 +2595,7 @@ void CegoDbHandler::collectData(const ListT<CegoField>& schema, const ListT<Cego
     }
 }
 
-int CegoDbHandler::numCollected() const
+unsigned CegoDbHandler::numCollected() const
 {
     if ( _protType == CegoDbHandler::XML )
     {
@@ -2718,7 +2721,7 @@ CegoDbHandler::ResultType CegoDbHandler::sendSerialReq()
     if ( req == Chain(SER_OK))
     {
 	_serMsg = _pSer->readChain();
-	_serAffected = _pSer->readChain().asInteger();
+	_serAffected = _pSer->readChain().asUnsigned();
 	return DB_OK;
     }
     else if ( req == Chain(SER_FIN))
