@@ -82,8 +82,9 @@ ListT<CegoDbThread::QueryEntry> CegoDbThread::getLastQuery() const
 
     P();
 
-    for ( int i=_queryList.Size()-1; i>=0; i--)
-	history.Insert(_queryList[i]);
+    if ( _queryList.Size() > 0 )
+	for ( unsigned i=_queryList.Size()-1; i>=0; i--)
+	    history.Insert(_queryList[i]);
     V();
     
     return history;
@@ -131,12 +132,12 @@ void CegoDbThread::abortSession()
     _pTabMng->abort();
 }
 
-int CegoDbThread::getErrorCode() const
+unsigned CegoDbThread::getErrorCode() const
 {
     return _errorCode;
 }
 
-void CegoDbThread::addReloadRequest(int tabSetId)
+void CegoDbThread::addReloadRequest(unsigned tabSetId)
 {
     _pPool->P(_idx);
     _loadList.Insert(tabSetId);
@@ -146,10 +147,10 @@ void CegoDbThread::addReloadRequest(int tabSetId)
 void CegoDbThread::checkReloadRequest()
 {   
     _pPool->P(_idx);
-    int *pTS = _loadList.First();
+    unsigned *pTS = _loadList.First();
     if ( pTS )
     {
-	int ts = *pTS;
+	unsigned ts = *pTS;
 	_loadList.Remove(*pTS);
 	_pPool->V(_idx);
 
@@ -189,7 +190,7 @@ void* CegoDbThread::job(void* arg)
 	_pPool->setTid(_idx, getTid());
 	_pPool->setThreadState(_idx, CegoDbThreadPool::READY);
 
-	int queueDelay = _pDBMng->getQueueDelay();
+	unsigned queueDelay = _pDBMng->getQueueDelay();
 
 	while ( ! _pPool->isTerminated() )
 	{
@@ -224,7 +225,7 @@ void* CegoDbThread::job(void* arg)
 			
 			Chain msg;
 			Chain module;
-			int line;
+			unsigned line;
 			
 			Chain exep;
 			while ( e.pop(module, line, msg) )
@@ -271,7 +272,7 @@ void* CegoDbThread::job(void* arg)
 	    {
 		Chain msg;
 		Chain module;
-		int line;	
+		unsigned line;	
 		Chain exep;
 		
 		while ( e.pop(module, line, msg) )
@@ -293,7 +294,7 @@ void* CegoDbThread::job(void* arg)
     return 0;
 }
 
-void CegoDbThread::loadObjects(int tabSetId)
+void CegoDbThread::loadObjects(unsigned tabSetId)
 {
     Chain tableSet = _pDBMng->getTabSetName(tabSetId);
 
@@ -355,7 +356,7 @@ void CegoDbThread::loadObjects(int tabSetId)
     }
 }
 
-void CegoDbThread::unloadObjects(int tabSetId)
+void CegoDbThread::unloadObjects(unsigned tabSetId)
 {
     try
     {	
@@ -368,7 +369,7 @@ void CegoDbThread::unloadObjects(int tabSetId)
     }
 }
 
-void CegoDbThread::invalidateObject(int tabSetId, const Chain& objName, CegoObject::ObjectType type)
+void CegoDbThread::invalidateObject(unsigned tabSetId, const Chain& objName, CegoObject::ObjectType type)
 {
     if ( type == CegoObject::VIEW )
     {
@@ -539,7 +540,7 @@ bool CegoDbThread::serveRequest(CegoDistDbHandler *pSH, CegoDbHandler::RequestTy
 	    
 	    pSH->getInsertArg(tableSet, tableName,fl);
 	    
-	    int tabSetId = _pDBMng->getTabSetId(tableSet);
+	    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
 	    
 	    CegoTableObject oe;
 	    _pTabMng->getObject(tabSetId, tableName, CegoObject::TABLE, oe);
@@ -601,7 +602,7 @@ bool CegoDbThread::serveRequest(CegoDistDbHandler *pSH, CegoDbHandler::RequestTy
 	    ListT<CegoField> idxList;
 	    
 	    pSH->getCreateTableArg(tableSet, tableName, fl, idxList);
-	    int tabSetId = _pDBMng->getTabSetId(tableSet);	    
+	    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);	    
 	    _pTabMng->createLocalDataTable(tabSetId, tableName, CegoObject::TABLE, fl, idxList);	  	    
 
 	    _pDBMng->addObject(tabSetId, tableName, CegoObject::TABLE); 
@@ -622,7 +623,7 @@ bool CegoDbThread::serveRequest(CegoDistDbHandler *pSH, CegoDbHandler::RequestTy
 	    ListT<CegoField> fl;
 	    
 	    pSH->getCreateViewArg(tableSet, viewName, fl, viewText);
-	    int tabSetId = _pDBMng->getTabSetId(tableSet);	    
+	    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);	    
 	    _pTabMng->createLocalView(tabSetId, viewName, fl, viewText);	  	    
 
 	    _pDBMng->addObject(tabSetId, viewName, CegoObject::VIEW);
@@ -637,7 +638,7 @@ bool CegoDbThread::serveRequest(CegoDistDbHandler *pSH, CegoDbHandler::RequestTy
 	    Chain procText;
 	    
 	    pSH->getCreateProcedureArg(tableSet, procName, procText);
-	    int tabSetId = _pDBMng->getTabSetId(tableSet);	    
+	    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);	    
 	    _pTabMng->createLocalProc(tabSetId, procName, procText);	  	    
 
 	    _pDBMng->addObject(tabSetId, procName, CegoObject::PROCEDURE);
@@ -693,7 +694,7 @@ bool CegoDbThread::serveRequest(CegoDistDbHandler *pSH, CegoDbHandler::RequestTy
 	    Chain objName;
 	    
 	    pSH->getDropTableArg(tableSet, objName, objType);	    
-	    int tabSetId = _pDBMng->getTabSetId(tableSet);
+	    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
 	    _pTabMng->dropObjectSynced(tabSetId, objName, objType);
 	    pSH->sendResponse(Chain("Drop ok"));	    
 	    break;	    
@@ -706,7 +707,7 @@ bool CegoDbThread::serveRequest(CegoDistDbHandler *pSH, CegoDbHandler::RequestTy
 	    ListT<CegoField> idxList;
 	    CegoObject::ObjectType type;	    
 	    pSH->getCreateIndexArg(tableSet, indexName, tableName, idxList, type);	    
-	    int tabSetId = _pDBMng->getTabSetId(tableSet);
+	    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
 
 	    bool isCached = false;
 	    _pTabMng->createIndexTableSynced(tabSetId, indexName, tableName, type, idxList, isCached);
@@ -718,7 +719,7 @@ bool CegoDbThread::serveRequest(CegoDistDbHandler *pSH, CegoDbHandler::RequestTy
 	}
 	case CegoDbHandler::OBJECTINFO:
 	{
-	    int tabSetId;
+	    unsigned tabSetId;
 	    Chain objName;
 	    CegoObject::ObjectType objType;
 	    
@@ -805,7 +806,7 @@ bool CegoDbThread::serveRequest(CegoDistDbHandler *pSH, CegoDbHandler::RequestTy
 	}
 	case CegoDbHandler::GETTABLE:
 	{
-	    int tabSetId;
+	    unsigned tabSetId;
 	    Chain tableName;
 	    CegoObject::ObjectType type;
 	    
@@ -820,7 +821,7 @@ bool CegoDbThread::serveRequest(CegoDistDbHandler *pSH, CegoDbHandler::RequestTy
 	    
 	    CegoObjectCursor *pOC = _pTabMng->getObjectCursor(tabSetId, tableName, tableName, type);
 	    
-	    int tupleCount=0;
+	    unsigned tupleCount=0;
 	    
 	    CegoDataPointer dp;
 	    bool moreTuple = _pTabMng->getFirstTuple(pOC, schema, dp);
@@ -849,7 +850,7 @@ bool CegoDbThread::serveRequest(CegoDistDbHandler *pSH, CegoDbHandler::RequestTy
 	}
 	case CegoDbHandler::GETOBJLIST:
 	{
-	    int tabSetId;
+	    unsigned tabSetId;
 	    CegoObject::ObjectType type;
 	    
 	    pSH->getGetObjectListArg(tabSetId, type);
@@ -868,7 +869,7 @@ bool CegoDbThread::serveRequest(CegoDistDbHandler *pSH, CegoDbHandler::RequestTy
 	    
 	    pSH->getGetObjectByTableListArg(tableSet, tableName);
 	    
-	    int tabSetId = _pDBMng->getTabSetId(tableSet);
+	    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
 	    
 	    
 	    ListT<CegoTableObject> idxList;
@@ -877,7 +878,7 @@ bool CegoDbThread::serveRequest(CegoDistDbHandler *pSH, CegoDbHandler::RequestTy
 	    ListT<CegoCheckObject> checkList;
 	    ListT<CegoTriggerObject> triggerList;
 	    ListT<CegoAliasObject> aliasList;
-	    int numInvalid;
+	    unsigned numInvalid;
 
 	    _pTabMng->setIgnoreInvalid(false);
 	    _pTabMng->getObjectListByTable(tabSetId, tableName, idxList, btreeList, keyList, checkList, triggerList, aliasList, numInvalid);
@@ -895,7 +896,7 @@ bool CegoDbThread::serveRequest(CegoDistDbHandler *pSH, CegoDbHandler::RequestTy
 	    
 	    pSH->getRenameArg(tableSet, objName, type, newObjName);
 	    
-	    int tabSetId = _pDBMng->getTabSetId(tableSet);
+	    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
 	    
 	    _pTabMng->renameObject(tabSetId, objName, type, newObjName);
 	    
@@ -912,7 +913,7 @@ bool CegoDbThread::serveRequest(CegoDistDbHandler *pSH, CegoDbHandler::RequestTy
 	    
 	    pSH->getReorgArg(tableSet, objName, type);
 	    
-	    int tabSetId = _pDBMng->getTabSetId(tableSet);
+	    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
 	    
 	    _pTabMng->reorgObject(tabSetId, objName, type);
 	    
@@ -924,11 +925,11 @@ bool CegoDbThread::serveRequest(CegoDistDbHandler *pSH, CegoDbHandler::RequestTy
 	{
 	    Chain tableSet;
 	    Chain escCmd;
-	    int timeout;
+	    unsigned timeout;
 	    
 	    pSH->getSyncArg(tableSet, escCmd, timeout);
 	    
-	    int tabSetId = _pDBMng->getTabSetId(tableSet);
+	    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
 	    
 	    _pDBMng->writeCheckPoint(tabSetId, true, true, _pTabMng->getLockHandle(), escCmd, timeout );
 	    
@@ -944,9 +945,9 @@ bool CegoDbThread::serveRequest(CegoDistDbHandler *pSH, CegoDbHandler::RequestTy
 	    
 	    pSH->getPageCountArg(tableSet, objName, type);
 	    
-	    int tabSetId = _pDBMng->getTabSetId(tableSet);
+	    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
 	    
-	    int pageCount = 0;
+	    unsigned pageCount = 0;
 	    _pTabMng->getPageCount(tabSetId, objName, type);
 	    
 	    pSH->sendPageCount(pageCount);
@@ -962,7 +963,7 @@ bool CegoDbThread::serveRequest(CegoDistDbHandler *pSH, CegoDbHandler::RequestTy
 	    
 	    pSH->getPutBlobArg(tableSet, blobSize);
 
-	    int tabSetId = _pDBMng->getTabSetId(tableSet);
+	    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
 
 	    NetHandler *pN = pSH->getNetHandler();
 
@@ -993,7 +994,7 @@ bool CegoDbThread::serveRequest(CegoDistDbHandler *pSH, CegoDbHandler::RequestTy
 #endif
 		pSH->sendBlobInfo(pageId);
 		
-		int freeInPage = bp.getChunkLen();
+		unsigned freeInPage = bp.getChunkLen();
 		char* pagePtr = bp.getChunkEntry();
 
 		unsigned long long blobRef = 0;
@@ -1006,7 +1007,7 @@ bool CegoDbThread::serveRequest(CegoDistDbHandler *pSH, CegoDbHandler::RequestTy
 		freeInPage -= sizeof(unsigned long long);
 		
 		char *bufPtr = 0; 
-		int availFromBuf = 0;
+		unsigned availFromBuf = 0;
 		
 		unsigned long long recvSize = 0;
 
@@ -1099,7 +1100,7 @@ bool CegoDbThread::serveRequest(CegoDistDbHandler *pSH, CegoDbHandler::RequestTy
 	    
 	    pSH->getGetBlobArg(tableSet, pageId);
 
-	    int tabSetId = _pDBMng->getTabSetId(tableSet);
+	    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
 
 	    NetHandler *pN = pSH->getNetHandler();	    	
 
@@ -1120,7 +1121,7 @@ bool CegoDbThread::serveRequest(CegoDistDbHandler *pSH, CegoDbHandler::RequestTy
 		{
 		    pN->recvAck();
 		    
-		    int chunkSize;
+		    unsigned chunkSize;
 
 		    // first page with written clob size, so we have to sub the size bytes
 		    if ( sentByte == 0 )
@@ -1188,7 +1189,7 @@ bool CegoDbThread::serveRequest(CegoDistDbHandler *pSH, CegoDbHandler::RequestTy
 	    
 	    pSH->getGetBlobArg(tableSet, pageId);
 
-	    int tabSetId = _pDBMng->getTabSetId(tableSet);
+	    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
 
 	    _pTabMng->decreaseBlobRef(tabSetId, pageId);
 
@@ -1204,7 +1205,7 @@ bool CegoDbThread::serveRequest(CegoDistDbHandler *pSH, CegoDbHandler::RequestTy
 	    
 	    pSH->getPutClobArg(tableSet, clobSize);
 
-	    int tabSetId = _pDBMng->getTabSetId(tableSet);
+	    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
 
 	    NetHandler *pN = pSH->getNetHandler();
 
@@ -1235,7 +1236,7 @@ bool CegoDbThread::serveRequest(CegoDistDbHandler *pSH, CegoDbHandler::RequestTy
 #endif
 		pSH->sendClobInfo(pageId);
 		
-		int freeInPage = bp.getChunkLen();
+		unsigned freeInPage = bp.getChunkLen();
 		char* pagePtr = bp.getChunkEntry();
 
 		unsigned long long clobRef = 0;
@@ -1248,7 +1249,7 @@ bool CegoDbThread::serveRequest(CegoDistDbHandler *pSH, CegoDbHandler::RequestTy
 		freeInPage -= sizeof(unsigned long long);
 		
 		char *bufPtr = 0; 
-		int availFromBuf = 0;
+		unsigned availFromBuf = 0;
 		
 		unsigned long long recvSize = 0;
 
@@ -1339,7 +1340,7 @@ bool CegoDbThread::serveRequest(CegoDistDbHandler *pSH, CegoDbHandler::RequestTy
 	    
 	    pSH->getGetClobArg(tableSet, pageId);
 
-	    int tabSetId = _pDBMng->getTabSetId(tableSet);
+	    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
 
 	    NetHandler *pN = pSH->getNetHandler();	    	
 
@@ -1360,7 +1361,7 @@ bool CegoDbThread::serveRequest(CegoDistDbHandler *pSH, CegoDbHandler::RequestTy
 		{
 		    pN->recvAck();
 		    
-		    int chunkSize;
+		    unsigned chunkSize;
 
 		    // first page with written clob size, so we have to sub the size bytes
 		    if ( sentByte == 0 )
@@ -1425,7 +1426,7 @@ bool CegoDbThread::serveRequest(CegoDistDbHandler *pSH, CegoDbHandler::RequestTy
 	    Chain tableSet;
 	    PageIdType pageId;
 	    pSH->getGetClobArg(tableSet, pageId);
-	    int tabSetId = _pDBMng->getTabSetId(tableSet);
+	    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
 	    _pTabMng->decreaseClobRef(tabSetId, pageId);
 	    pSH->sendResponse(Chain("Clob deleted"));
 	    
@@ -1437,7 +1438,7 @@ bool CegoDbThread::serveRequest(CegoDistDbHandler *pSH, CegoDbHandler::RequestTy
 	    
 	    Chain tableSet;
 	    pSH->getArgValue(XML_TABLESET_ATTR, tableSet);
-	    int tabSetId = _pDBMng->getTabSetId(tableSet);
+	    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
 	    _pTabMng->beginTransaction(tabSetId, true);
 	    pSH->sendResponse(Chain("Transaction started"));	    
 	    break;	    
@@ -1448,7 +1449,7 @@ bool CegoDbThread::serveRequest(CegoDistDbHandler *pSH, CegoDbHandler::RequestTy
 	    
 	    Chain tableSet;
 	    pSH->getArgValue(XML_TABLESET_ATTR, tableSet);
-	    int tabSetId = _pDBMng->getTabSetId(tableSet);
+	    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
 	    _pTabMng->commitTransaction(tabSetId, true);
 	    pSH->sendResponse(Chain("Transaction committed"));
 			
@@ -1460,7 +1461,7 @@ bool CegoDbThread::serveRequest(CegoDistDbHandler *pSH, CegoDbHandler::RequestTy
 	    
 	    Chain tableSet;
 	    pSH->getArgValue(XML_TABLESET_ATTR, tableSet);
-	    int tabSetId = _pDBMng->getTabSetId(tableSet);
+	    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
 	    _pTabMng->rollbackTransaction(tabSetId, true);
 	    pSH->sendResponse(Chain("Transaction rollbacked"));			
 	    break;	    
@@ -1471,7 +1472,7 @@ bool CegoDbThread::serveRequest(CegoDistDbHandler *pSH, CegoDbHandler::RequestTy
 	    
 	    Chain tableSet;
 	    pSH->getArgValue(XML_TABLESET_ATTR, tableSet);
-	    int tabSetId = _pDBMng->getTabSetId(tableSet);	    
+	    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);	    
 	    pSH->sendTID(_pTabMng->getTID(tabSetId));	    
 	    break;	    
 	}
@@ -1494,7 +1495,7 @@ bool CegoDbThread::serveRequest(CegoDistDbHandler *pSH, CegoDbHandler::RequestTy
     {	
 	Chain msg;
 	Chain module;
-	int line;
+	unsigned line;
 	
 	Chain exep;
 	while ( e.pop(module, line, msg) )
@@ -1541,7 +1542,7 @@ void CegoDbThread::addHistory(unsigned long long ts, const Chain& queryString, u
 	    costEntry.setCostOrder();
 	    _costTree.Insert(costEntry);
 	    QueryEntry *pFirst = _costTree.First();
-	    if ( pFirst && (int)_costTree.Size() >= _numCost )
+	    if ( pFirst && (unsigned)_costTree.Size() >= _numCost )
 		_costTree.Remove(*pFirst);
 	}
 	
