@@ -48,7 +48,7 @@ CegoDbThreadPool::CegoDbThreadPool() : Thread()
     queueLock.init(LCKMNG_LOCKWAITDELAY);
 }
 
-CegoDbThreadPool::CegoDbThreadPool(int poolLimit, CegoDatabaseManager *pDBMng, CegoDbHandler::ProtocolType protType)  : Thread()
+CegoDbThreadPool::CegoDbThreadPool(unsigned poolLimit, CegoDatabaseManager *pDBMng, CegoDbHandler::ProtocolType protType)  : Thread()
 {
     _poolLimit = poolLimit;
     _samplePos = 0;
@@ -61,7 +61,7 @@ CegoDbThreadPool::~CegoDbThreadPool()
 {
     _terminated=true;
 
-    int i=0;
+    unsigned i=0;
     while ( i < _poolLimit )
     {
 	_threadList[i]->abortSession();	
@@ -69,7 +69,7 @@ CegoDbThreadPool::~CegoDbThreadPool()
     }
 
     _joined=false;
-    int count=0;
+    unsigned count=0;
     while ( _joined == false && count < POOL_TERMWAIT )
     {
 	Sleeper s;
@@ -88,7 +88,7 @@ CegoDbThreadPool::~CegoDbThreadPool()
 	cancel();
     }
     
-    for ( int i = 0; i < _poolLimit; i++ )
+    for ( unsigned i = 0; i < _poolLimit; i++ )
     {
 	delete _threadList[i];
 	delete thrLockArray[i];
@@ -99,7 +99,7 @@ CegoDbThreadPool::~CegoDbThreadPool()
     delete _threadId;
     delete _threadLoad;
 
-    for ( int i = 0; i < THRMNG_NUMLOADSAMPLE; i++ )
+    for ( unsigned i = 0; i < THRMNG_NUMLOADSAMPLE; i++ )
     {
 	delete _threadIdle[i];
     }
@@ -108,12 +108,12 @@ CegoDbThreadPool::~CegoDbThreadPool()
     delete thrLockArray;
 }
 
-void CegoDbThreadPool::P(int i)
+void CegoDbThreadPool::P(unsigned i)
 {
     thrLockArray[i]->writeLock(DBM_LOCKTIMEOUT);
 }
 
-void CegoDbThreadPool::V(int i)
+void CegoDbThreadPool::V(unsigned i)
 {
     thrLockArray[i]->unlock();
 }
@@ -123,7 +123,7 @@ void  CegoDbThreadPool::syncToReady()
     queueLock.init(LCKMNG_LOCKWAITDELAY, __lockStatOn);
     thrLockArray = new ThreadLock*[_poolLimit];
 
-    for (int i = 0; i<_poolLimit; i++)
+    for (unsigned i = 0; i<_poolLimit; i++)
     {
         thrLockArray[i] = new ThreadLock(Chain("DBTHRLCK") + Chain(i));
         thrLockArray[i]->init(LCKMNG_LOCKWAITDELAY, __lockStatOn);
@@ -138,7 +138,7 @@ void  CegoDbThreadPool::syncToReady()
     _threadLoad = (unsigned long long*)malloc(_poolLimit * sizeof(unsigned long long));
     _numRequest = (unsigned long long*)malloc(_poolLimit * sizeof(unsigned long long));
     _numQueryRequest = (unsigned long long*)malloc(_poolLimit * sizeof(unsigned long long));
-    for ( int i = 0; i < THRMNG_NUMLOADSAMPLE; i++ )
+    for ( unsigned i = 0; i < THRMNG_NUMLOADSAMPLE; i++ )
     {
 	_threadIdle[i] = (unsigned long long*)malloc(_poolLimit * sizeof(unsigned long long));
     }
@@ -147,7 +147,7 @@ void  CegoDbThreadPool::syncToReady()
 
     _terminated=false;
 
-    int i=0;
+    unsigned i=0;
     while ( i < _poolLimit )
     {
 	_threadState[i] = STARTING;
@@ -157,7 +157,7 @@ void  CegoDbThreadPool::syncToReady()
 
 	_threadId[i]=i;
 	_threadLoad[i]=0;
-	for ( int j = 0; j < THRMNG_NUMLOADSAMPLE; j++ )
+	for ( unsigned j = 0; j < THRMNG_NUMLOADSAMPLE; j++ )
 	{
 	    _threadIdle[j][i]=0;
 	}
@@ -165,11 +165,11 @@ void  CegoDbThreadPool::syncToReady()
 	i++;
     }
     
-    int numReady=0;
+    unsigned numReady=0;
     while ( numReady < _poolLimit )
     {	
 	numReady=0;
-	int i=0;
+	unsigned i=0;
 	while ( i < _poolLimit )
 	{
 	    if ( _threadState[i] == READY )
@@ -183,9 +183,9 @@ void  CegoDbThreadPool::syncToReady()
     _pDBMng->log(_modId, Logger::NOTICE, Chain("All db threads ready"));
 }
 
-void  CegoDbThreadPool::loadObjects(int tabSetId)
+void  CegoDbThreadPool::loadObjects(unsigned tabSetId)
 {
-    int i=0;
+    unsigned i=0;
     while ( i < _poolLimit )
     {
 	_threadList[i]->addReloadRequest(tabSetId);
@@ -193,9 +193,9 @@ void  CegoDbThreadPool::loadObjects(int tabSetId)
     }
 }
 
-void  CegoDbThreadPool::unloadObjects(int tabSetId)
+void  CegoDbThreadPool::unloadObjects(unsigned tabSetId)
 {
-    int i=0;
+    unsigned i=0;
     while ( i < _poolLimit )
     {
 	_threadList[i]->unloadObjects(tabSetId);
@@ -203,9 +203,9 @@ void  CegoDbThreadPool::unloadObjects(int tabSetId)
     }
 }
 
-void CegoDbThreadPool::invalidateObject(int tabSetId, const Chain& objName, CegoObject::ObjectType type)
+void CegoDbThreadPool::invalidateObject(unsigned tabSetId, const Chain& objName, CegoObject::ObjectType type)
 {
-    int i=0;
+    unsigned i=0;
     while ( i < _poolLimit )
     {	
 	try
@@ -221,12 +221,12 @@ void CegoDbThreadPool::invalidateObject(int tabSetId, const Chain& objName, Cego
     }    
 }
 
-int CegoDbThreadPool::getPoolLimit() const
+unsigned CegoDbThreadPool::getPoolLimit() const
 {
     return _poolLimit;
 }
 
-void CegoDbThreadPool::getThreadInfo(int i, unsigned long long& numRequest, unsigned long long& numQueryRequest, unsigned long long& threadLoad, unsigned long long& numAllocated, CegoDbThreadPool::ThreadState& state, Chain& lastAction)
+void CegoDbThreadPool::getThreadInfo(unsigned i, unsigned long long& numRequest, unsigned long long& numQueryRequest, unsigned long long& threadLoad, unsigned long long& numAllocated, CegoDbThreadPool::ThreadState& state, Chain& lastAction)
 {
     state = _threadState[i];
     numRequest = _numRequest[i];
@@ -236,17 +236,17 @@ void CegoDbThreadPool::getThreadInfo(int i, unsigned long long& numRequest, unsi
     lastAction = _threadList[i]->lastAction();
 }
 
-void CegoDbThreadPool::getThreadHistory(int i, ListT<CegoDbThread::QueryEntry>& queryList)
+void CegoDbThreadPool::getThreadHistory(unsigned i, ListT<CegoDbThread::QueryEntry>& queryList)
 {
     if ( i < _poolLimit )
 	queryList = _threadList[i]->getLastQuery();
 }
 
-void CegoDbThreadPool::getQueryHistoryLast(int numLast, ListT<CegoDbThread::QueryEntry>& queryList)
+void CegoDbThreadPool::getQueryHistoryLast(unsigned numLast, ListT<CegoDbThread::QueryEntry>& queryList)
 {    
     TreeT<CegoDbThread::QueryEntry> queryTree;
     
-    int i=0;
+    unsigned i=0;
     while ( i < _poolLimit )
     {
 	ListT<CegoDbThread::QueryEntry> threadQueryList;
@@ -273,11 +273,11 @@ void CegoDbThreadPool::getQueryHistoryLast(int numLast, ListT<CegoDbThread::Quer
     }
 }
 
-void CegoDbThreadPool::getQueryHistoryCost(int numLast, ListT<CegoDbThread::QueryEntry>& queryList)
+void CegoDbThreadPool::getQueryHistoryCost(unsigned numLast, ListT<CegoDbThread::QueryEntry>& queryList)
 {
     TreeT<CegoDbThread::QueryEntry> queryTree;
     
-    int i=0;
+    unsigned i=0;
     while ( i < _poolLimit )
     {
 	ListT<CegoDbThread::QueryEntry> threadQueryList;
@@ -303,37 +303,37 @@ void CegoDbThreadPool::getQueryHistoryCost(int numLast, ListT<CegoDbThread::Quer
     }
 }
 
-void CegoDbThreadPool::setState(int i, CegoDbThreadPool::ThreadState state)
+void CegoDbThreadPool::setState(unsigned i, CegoDbThreadPool::ThreadState state)
 {
     _threadState[i] = state;
 }
 
-void CegoDbThreadPool::incNumRequest(int i)
+void CegoDbThreadPool::incNumRequest(unsigned i)
 {
     _numRequest[i]++;
 }
 
-void CegoDbThreadPool::incNumQueryRequest(int i)
+void CegoDbThreadPool::incNumQueryRequest(unsigned i)
 {
     _numQueryRequest[i]++;
 }
 
-void CegoDbThreadPool::addThreadIdle(int i, unsigned long long usec)
+void CegoDbThreadPool::addThreadIdle(unsigned i, unsigned long long usec)
 {    
     _threadIdle[_samplePos][i] += usec;
 }
 
-void CegoDbThreadPool::setTid(int i, unsigned long long tid)
+void CegoDbThreadPool::setTid(unsigned i, unsigned long long tid)
 {
     _threadId[i] = tid;
 }
 
-void CegoDbThreadPool::setThreadState(int i, CegoDbThreadPool::ThreadState state)
+void CegoDbThreadPool::setThreadState(unsigned i, CegoDbThreadPool::ThreadState state)
 {
     _threadState[i] = state;
 }
 
-void  CegoDbThreadPool::abortThread(int i)
+void  CegoDbThreadPool::abortThread(unsigned i)
 {
     _threadList[i]->abortSession();
 }
@@ -352,13 +352,13 @@ void* CegoDbThreadPool::job(void* arg)
 	    net.serve6(_dataPortNo);
 
 	unsigned long long usedTime[THRMNG_NUMLOADSAMPLE];
-	for ( int i = 0; i < THRMNG_NUMLOADSAMPLE; i++ )
+	for ( unsigned i = 0; i < THRMNG_NUMLOADSAMPLE; i++ )
 	{
 	    usedTime[i] = 0;
 	}
 
-	int selectTimeout = _pDBMng->getSelectTimeout();
-	int queueDelay = _pDBMng->getQueueDelay();
+	unsigned selectTimeout = _pDBMng->getSelectTimeout();
+	unsigned queueDelay = _pDBMng->getQueueDelay();
 	
 	while ( ! _terminated ) 
 	{
@@ -404,20 +404,29 @@ void* CegoDbThreadPool::job(void* arg)
 	    
 	    if ( pHandle )
 	    {
-		_pDBMng->log(_modId, Logger::NOTICE, Chain("Connection request from <") + pHandle->getSource() + Chain(">"));		
-		lockQueue();
+		_pDBMng->log(_modId, Logger::NOTICE, Chain("Connection request from <") + pHandle->getSource() + Chain(">"));
 
-		if ( _requestQueue.Size() < NETMNG_MAXQUEUELEN )
+		if ( pHandle->getMsgSize() > 0 )
 		{
-		    _requestQueue.Insert(pHandle);
+		    lockQueue();
+		    
+		    if ( _requestQueue.Size() < NETMNG_MAXQUEUELEN )
+		    {
+			_requestQueue.Insert(pHandle);
+		    }
+		    else
+		    {
+			delete pHandle;
+			_pDBMng->log(_modId, Logger::NOTICE, Chain("Rejected incoming request since connection queue is full ( ") +  Chain(NETMNG_MAXQUEUELEN) + Chain(" max )"));
+		    }
+		    
+		    unlockQueue();		    
 		}
 		else
 		{
 		    delete pHandle;
-		    _pDBMng->log(_modId, Logger::NOTICE, Chain("Rejected incoming request since connection queue is full ( ") +  Chain(NETMNG_MAXQUEUELEN) + Chain(" max )"));
+		    _pDBMng->log(_modId, Logger::NOTICE, Chain("Rejected empty request message"));
 		}
-		
-		unlockQueue();
 	    }
 
 	    tim.stop();
@@ -428,12 +437,12 @@ void* CegoDbThreadPool::job(void* arg)
 	    tim.start();
 	   
 	    // calculate load
-	    int i=0;
+	    unsigned i=0;
 	    while ( i < _poolLimit )
 	    {
 		unsigned long long ut=0;
 		unsigned long long ti=0;
-		for ( int j=0; j< THRMNG_NUMLOADSAMPLE; j++ )
+		for ( unsigned j=0; j< THRMNG_NUMLOADSAMPLE; j++ )
 		{
 		    ut+=usedTime[j];
 		    ti+=_threadIdle[j][i];
@@ -450,12 +459,12 @@ void* CegoDbThreadPool::job(void* arg)
 
 	    _samplePos = ( _samplePos + 1 ) % THRMNG_NUMLOADSAMPLE;
 	   
-	    for ( int i = 0; i < _poolLimit; i++ )
+	    for ( unsigned i = 0; i < _poolLimit; i++ )
 	    {
 		_threadIdle[_samplePos][i]=0;
 	    }	    
 	}
-	int i=0;
+	unsigned i=0;
 	while ( i < _poolLimit )
 	{
 #ifdef CGDEBUG	
@@ -470,7 +479,7 @@ void* CegoDbThreadPool::job(void* arg)
     {
 	Chain msg;
 	e.pop(msg);	
-	_pDBMng->log(_modId, Logger::LOGERR, Chain("Db Thread start failed : ") +  msg);	
+	_pDBMng->log(_modId, Logger::LOGERR, Chain("Db Thread failed : ") +  msg);	
 	_terminated=true;
     }
 
@@ -480,7 +489,7 @@ void* CegoDbThreadPool::job(void* arg)
 
 bool CegoDbThreadPool::isBusy()
 {
-    int i=0;
+    unsigned i=0;
     while ( i < _poolLimit )
     {
 	if ( _threadState[i] == BUSY )
@@ -526,7 +535,7 @@ void CegoDbThreadPool::unlockQueue()
     queueLock.unlock();
 }
 
-void CegoDbThreadPool::getLockStat(Chain& lockName, int& lockCount, unsigned long long &numRdLock, unsigned long long &numWrLock, unsigned long long &sumRdDelay, unsigned long long &sumWrDelay)
+void CegoDbThreadPool::getLockStat(Chain& lockName, unsigned& lockCount, unsigned long long &numRdLock, unsigned long long &numWrLock, unsigned long long &sumRdDelay, unsigned long long &sumWrDelay)
 {
     lockName = queueLock.getId();
     lockCount = queueLock.numLockTry();
@@ -543,7 +552,7 @@ void CegoDbThreadPool::getLockStat(Chain& lockName, int& lockCount, unsigned lon
 	sumWrDelay = queueLock.sumWriteDelay() / LCKMNG_DELRES;
 }
 
-void CegoDbThreadPool::getAggThreadLockStat(Chain& lockGroup, int& numLock, int& lockCount, unsigned long long &numRdLock, unsigned long long &numWrLock, unsigned long long &sumRdDelay, unsigned long long &sumWrDelay)
+void CegoDbThreadPool::getAggThreadLockStat(Chain& lockGroup, unsigned& numLock, unsigned& lockCount, unsigned long long &numRdLock, unsigned long long &numWrLock, unsigned long long &sumRdDelay, unsigned long long &sumWrDelay)
 {
     lockGroup = Chain("DBTHRLCK");
     
@@ -554,7 +563,7 @@ void CegoDbThreadPool::getAggThreadLockStat(Chain& lockGroup, int& numLock, int&
     sumWrDelay = 0;
     numLock = 0;
 
-    for ( int i = 0; i<_poolLimit; i++)
+    for ( unsigned i = 0; i<_poolLimit; i++)
     {	
 	numLock++;
 	lockCount += thrLockArray[i]->numLockTry();
