@@ -84,22 +84,22 @@ public:
     
     CegoFunction(FunctionType funcType);
     CegoFunction(FunctionType funcType, ListT<CegoExpr*>& exprList);
-    CegoFunction(char* buf, CegoDistManager *pTabMng, CegoProcBlock *pBlock, int tabSetId);
-    CegoFunction(CegoDistManager* pTabMng, int tabSetId, CegoFunction::FunctionType type);
-    CegoFunction(CegoDistManager* pTabMng, int tabSetId, const Chain& funcName, ListT<CegoExpr*>& exprList);
+    CegoFunction(char* buf, CegoDistManager *pTabMng, CegoProcBlock *pBlock, unsigned tabSetId);
+    CegoFunction(CegoDistManager* pTabMng, unsigned tabSetId, CegoFunction::FunctionType type);
+    CegoFunction(CegoDistManager* pTabMng, unsigned tabSetId, const Chain& funcName, ListT<CegoExpr*>& exprList);
     
     ~CegoFunction();
 
     void cleanUp();
 
-    void setTabSetId(int tabSetId);
+    void setTabSetId(unsigned tabSetId);
     
-    int getTabSetId() const;
+    unsigned getTabSetId() const;
     Chain getName() const;
 	
     CegoDataType getReturnType();
-    int getReturnTypeLen(const ListT<CegoField>& fl);
-    int getReturnTypeDim();
+    unsigned getReturnTypeLen(const ListT<CegoField>& fl);
+    unsigned getReturnTypeDim();
 
     ListT<CegoExpr*>& getExprList();
     void getFieldList(ListT<CegoField>& fl, ListT<CegoField>** pFLA) const;
@@ -111,7 +111,7 @@ public:
     void clearAttrCache();
 
     ListT<CegoAttrDesc*> getAttrRefList() const;
-    int evalReferences(CegoContentObject *pCO, const ListT<CegoField>& fl);
+    unsigned evalReferences(CegoContentObject *pCO, const ListT<CegoField>& fl);
 
     void setCounterId(const Chain& counterId);
     void setCounterExpr(CegoExpr* pCounterExpr);
@@ -121,12 +121,12 @@ public:
     CegoFieldValue evalFieldValue(ListT<CegoField>** pFLA, CegoProcBlock *pBlock);
     
     Chain getId(CegoProcBlock *pBlock) const;
-    Chain toChain(int defTabSetId, const Chain& indent = Chain("")) const;
+    Chain toChain(unsigned defTabSetId, const Chain& indent = Chain("")) const;
     Chain dbFormat(CegoDatabaseFormater *pForm) const;
     
     void encode(char *buf, CegoProcBlock *pBlock);
-    void decode(char *buf, CegoDistManager* pGTM, CegoProcBlock *pBlock, int tabSetId);
-    int getEncodingLength(CegoProcBlock *pBlock) const;
+    void decode(char *buf, CegoDistManager* pGTM, CegoProcBlock *pBlock, unsigned tabSetId);
+    unsigned getEncodingLength(CegoProcBlock *pBlock) const;
 
     CegoFunction* clone(bool isAttrRef = false);
 
@@ -138,7 +138,7 @@ public:
     
 private:
 
-    CegoProcedure* loadProcedure(int tabSetId, const Chain& procName) const;
+    CegoProcedure* loadProcedure(unsigned tabSetId, const Chain& procName) const;
   
     CegoDistManager* _pTabMng;
     CegoProcedure* _pProc;	    
@@ -146,6 +146,6 @@ private:
     Chain _counterId;  
     FunctionType _type;
     ListT<CegoExpr*> _exprList;
-    int _tabSetId;
+    unsigned _tabSetId;
 };
 #endif
