@@ -56,7 +56,7 @@ CegoLogThreadPool::CegoLogThreadPool(CegoDatabaseManager *pDBMng) : Thread()
     _modId = _pDBMng->getModId("CegoLogThreadPool");
 }
 
-CegoLogThreadPool::CegoLogThreadPool(int poolLimit, CegoDatabaseManager *pDBMng) : Thread()
+CegoLogThreadPool::CegoLogThreadPool(unsigned poolLimit, CegoDatabaseManager *pDBMng) : Thread()
 {
     queueLock.init(LCKMNG_LOCKWAITDELAY, __lockStatOn);
 
@@ -70,7 +70,7 @@ CegoLogThreadPool::CegoLogThreadPool(int poolLimit, CegoDatabaseManager *pDBMng)
     _threadId = (unsigned long long*)malloc(_poolLimit * sizeof(unsigned long long));
 
     _threadLoad = (unsigned long long*)malloc(_poolLimit * sizeof(unsigned long long));
-    for ( int i = 0; i < THRMNG_NUMLOADSAMPLE; i++ )
+    for ( unsigned i = 0; i < THRMNG_NUMLOADSAMPLE; i++ )
     {
 	_threadIdle[i] = (unsigned long long*)malloc(_poolLimit * sizeof(unsigned long long));
     }
@@ -81,7 +81,7 @@ CegoLogThreadPool::CegoLogThreadPool(int poolLimit, CegoDatabaseManager *pDBMng)
 
     _terminated=false;
 
-    int i=0;
+    unsigned i=0;
     while ( i < _poolLimit )
     {	
 	_threadState[i] = READY;
@@ -90,7 +90,7 @@ CegoLogThreadPool::CegoLogThreadPool(int poolLimit, CegoDatabaseManager *pDBMng)
 	_numRequest[i]=0;
 
 	_threadLoad[i]=0;
-	for ( int j = 0; j < THRMNG_NUMLOADSAMPLE; j++ )
+	for ( unsigned j = 0; j < THRMNG_NUMLOADSAMPLE; j++ )
 	{
 	    _threadIdle[j][i]=0;
 	}
@@ -107,7 +107,7 @@ CegoLogThreadPool::~CegoLogThreadPool()
     _joined=false;
     _terminated=true;
 
-    int count=0;
+    unsigned count=0;
     while ( _joined == false && count < POOL_TERMWAIT )
     {
 	Sleeper s;
@@ -128,7 +128,7 @@ CegoLogThreadPool::~CegoLogThreadPool()
 
     if ( _poolLimit > 0 )
     {    
-	int i=0;
+	unsigned i=0;
 	while ( i < _poolLimit )
 	{
 	    delete _threadList[i];
@@ -137,7 +137,7 @@ CegoLogThreadPool::~CegoLogThreadPool()
 	delete _threadId;
 
 	delete _threadLoad;
-	for ( int i = 0; i < THRMNG_NUMLOADSAMPLE; i++ )
+	for ( unsigned i = 0; i < THRMNG_NUMLOADSAMPLE; i++ )
 	{
 	    delete _threadIdle[i];
 	}
@@ -147,12 +147,12 @@ CegoLogThreadPool::~CegoLogThreadPool()
     }
 }
 
-int CegoLogThreadPool::getPoolLimit() const
+unsigned CegoLogThreadPool::getPoolLimit() const
 {
     return _poolLimit;
 }
 
-void CegoLogThreadPool::getThreadInfo(int i, unsigned long long& numRequest, unsigned long long& threadLoad, CegoLogThreadPool::ThreadState& state, Chain& action)
+void CegoLogThreadPool::getThreadInfo(unsigned i, unsigned long long& numRequest, unsigned long long& threadLoad, CegoLogThreadPool::ThreadState& state, Chain& action)
 {
     state = _threadState[i];
     numRequest = _numRequest[i];
@@ -160,22 +160,22 @@ void CegoLogThreadPool::getThreadInfo(int i, unsigned long long& numRequest, uns
     action = _threadList[i]->lastAction();
 }
 
-void CegoLogThreadPool::setState(int i, CegoLogThreadPool::ThreadState state)
+void CegoLogThreadPool::setState(unsigned i, CegoLogThreadPool::ThreadState state)
 {
     _threadState[i] = state;
 }
 
-void CegoLogThreadPool::incNumRequest(int i)
+void CegoLogThreadPool::incNumRequest(unsigned i)
 {
     _numRequest[i]++;
 }
 
-void CegoLogThreadPool::addThreadIdle(int i, unsigned long long usec)
+void CegoLogThreadPool::addThreadIdle(unsigned i, unsigned long long usec)
 {
     _threadIdle[_samplePos][i] += usec;
 }
 
-void CegoLogThreadPool::setTid(int i, unsigned long long tid)
+void CegoLogThreadPool::setTid(unsigned i, unsigned long long tid)
 {
     _threadId[i] = tid;
 }
@@ -217,13 +217,13 @@ void* CegoLogThreadPool::job(void* arg)
 		net.serve6(_logPortNo);
 	    
 	    unsigned long long usedTime[THRMNG_NUMLOADSAMPLE];
-	    for ( int i = 0; i < THRMNG_NUMLOADSAMPLE; i++ )
+	    for ( unsigned i = 0; i < THRMNG_NUMLOADSAMPLE; i++ )
 	    {
 		usedTime[i] = 0;
 	    }
 
-	    int selectTimeout = _pDBMng->getSelectTimeout();
-	    int queueDelay = _pDBMng->getQueueDelay();
+	    unsigned selectTimeout = _pDBMng->getSelectTimeout();
+	    unsigned queueDelay = _pDBMng->getQueueDelay();
 	    
 	    while ( ! _terminated ) 
 	    {
@@ -266,19 +266,28 @@ void* CegoLogThreadPool::job(void* arg)
 		if ( pHandle )
 		{		    
 		    _pDBMng->log(_modId, Logger::NOTICE, Chain("Connection request from <") + pHandle->getSource() + Chain(">"));
-		    lockQueue();
-		    
-		    if ( _requestQueue.Size() < NETMNG_MAXQUEUELEN )
-		    {
-			_requestQueue.Insert(pHandle);
+		    if ( pHandle->getMsgSize() > 0 )
+		    {	
+			lockQueue();
+			
+			if ( _requestQueue.Size() < NETMNG_MAXQUEUELEN )
+			{
+			    _requestQueue.Insert(pHandle);
+			}
+			else
+			{
+			    delete pHandle;
+			    _pDBMng->log(_modId, Logger::NOTICE, Chain("Rejected incoming request since connection queue is full ( ") +  Chain(NETMNG_MAXQUEUELEN) + Chain(" max )"));
+			}
+		    	
+			unlockQueue();
+			
 		    }
 		    else
 		    {
 			delete pHandle;
-			_pDBMng->log(_modId, Logger::NOTICE, Chain("Rejected incoming request since connection queue is full ( ") +  Chain(NETMNG_MAXQUEUELEN) + Chain(" max )"));
-		    }
-		    		    		    		   
-		    unlockQueue();
+			_pDBMng->log(_modId, Logger::NOTICE, Chain("Rejected empty request message"));
+		    }		    
 		}
 		
 		try
@@ -300,12 +309,12 @@ void* CegoLogThreadPool::job(void* arg)
 		tim.start();
 		
 		// calculate load
-		int i=0;
+		unsigned i=0;
 		while ( i < _poolLimit )
 		{
 		    unsigned long long ut=0;
 		    unsigned long long ti=0;
-		    for ( int j=0; j< THRMNG_NUMLOADSAMPLE; j++ )
+		    for ( unsigned j=0; j< THRMNG_NUMLOADSAMPLE; j++ )
 		    {
 			ut+=usedTime[j];
 			ti+=_threadIdle[j][i];
@@ -322,13 +331,13 @@ void* CegoLogThreadPool::job(void* arg)
 		
 		_samplePos = ( _samplePos + 1 ) % THRMNG_NUMLOADSAMPLE;
 		
-		for ( int i = 0; i < _poolLimit; i++ )
+		for ( unsigned i = 0; i < _poolLimit; i++ )
 		{
 		    _threadIdle[_samplePos][i]=0;
 		}
 	    }
 
-	    int i=0;
+	    unsigned i=0;
 	    while ( i < _poolLimit )
 	    {
 #ifdef CGDEBUG	
@@ -384,7 +393,7 @@ void CegoLogThreadPool::unlockQueue()
     queueLock.unlock();
 }
 
-void CegoLogThreadPool::getLockStat(Chain& lockName, int& lockCount, unsigned long long &numRdLock, unsigned long long &numWrLock, unsigned long long &sumRdDelay, unsigned long long &sumWrDelay)
+void CegoLogThreadPool::getLockStat(Chain& lockName, unsigned& lockCount, unsigned long long &numRdLock, unsigned long long &numWrLock, unsigned long long &sumRdDelay, unsigned long long &sumWrDelay)
 {
     lockName = queueLock.getId();
     lockCount = queueLock.numLockTry();
@@ -412,7 +421,7 @@ void CegoLogThreadPool::shiftRedoLogs()
 
     while ( pActiveTS )
     {
-	int tabSetId = _pDBMng->getTabSetId(*pActiveTS);
+	unsigned tabSetId = _pDBMng->getTabSetId(*pActiveTS);
 
 	ListT<Chain> archPathList;
 	ListT<Chain> archIdList;
@@ -449,15 +458,15 @@ void CegoLogThreadPool::copyLog(const Chain& tableSet, const Chain& logFileName,
     
     logFile.open(File::READ);
 
-    int offset;
-    logFile.readByte((char*)&offset, sizeof(int));
+    unsigned offset;
+    logFile.readByte((char*)&offset, sizeof(unsigned));
 
-    int pos = sizeof(int);
+    unsigned pos = sizeof(unsigned);
 
     if ( pos < offset)
     {	
-	int len;
-	logFile.readByte((char*)&len, sizeof(int));	
+	unsigned len;
+	logFile.readByte((char*)&len, sizeof(unsigned));	
 	
 	char* buf = new char[len];
 	
