@@ -159,7 +159,7 @@ extern BigDecimal::RoundMode __roundMode;
 
 // how to format date on default
 extern Chain __dateTimeFormat;
-extern int __dateLength;
+extern unsigned __dateLength;
 // valid date time scan formats
 extern ListT<Chain> __dateFormatList;
 // since the date format list is accessed by several threads, we have to provide a mutex lock for it
@@ -182,7 +182,7 @@ int importTableSet(GetLongOpt& longOpt, XPortFormat format);
 int exportTableSet(GetLongOpt& longOpt, XPortFormat format);
 int runBatch(GetLongOpt& longOpt);
 int runDaemon(GetLongOpt& longOpt);
-bool getPoolInfo(const Chain& poolSize, int& numSeg, int& segSize);
+bool getPoolInfo(const Chain& poolSize, unsigned& numSeg, unsigned& segSize);
 int setQueryCache(GetLongOpt& longOpt);
 
 int main(int argc, char **argv)
@@ -301,7 +301,7 @@ int main(int argc, char **argv)
     // parameter validation
 
     Chain poolSize = longOpt.getOptValue("poolsize");
-    int numSeg, segSize;
+    unsigned numSeg, segSize;
     if ( getPoolInfo(poolSize, numSeg, segSize) == false )
     {
 	cerr << "Invalid value for poolsize : " <<  poolSize << endl;
@@ -309,21 +309,21 @@ int main(int argc, char **argv)
     }
 
     Chain numDbThread = longOpt.getOptValue("numdbthread");
-    if ( numDbThread.asInteger() <= 0 )
+    if ( numDbThread.asUnsigned() <= 0 )
     {
 	cerr << "Invalid value for numdbthread : " << numDbThread << endl;
 	exit(1);
     }
 
     Chain numAdminThread = longOpt.getOptValue("numadminthread");
-    if ( numAdminThread.asInteger() <= 0 )
+    if ( numAdminThread.asUnsigned() <= 0 )
     {
 	cerr << "Invalid value for numadminthread : " << numAdminThread << endl;
 	exit(1);
     }
 
     Chain numLogThread = longOpt.getOptValue("numlogthread");
-    if ( numLogThread.asInteger() <= 0 )
+    if ( numLogThread.asUnsigned() <= 0 )
     {
 	cerr << "Invalid value for numlogthread : " << numLogThread << endl;
 	exit(1);
@@ -526,7 +526,7 @@ int init(GetLongOpt& longOpt)
 
 	pDBMng = new CegoDatabaseManager(dbXML, lockFile, lockExpire, logFile, progName);
 
-	pDBMng->initXml(dbName, pgsize.asInteger(), hostname, dbport.asInteger(), admport.asInteger(), logport.asInteger(), pidfile, logLevel,
+	pDBMng->initXml(dbName, pgsize.asUnsigned(), hostname, dbport.asUnsigned(), admport.asUnsigned(), logport.asUnsigned(), pidfile, logLevel,
 			csmode, qescmode == Chain(XML_ON_VALUE) );
 	
 	delete pDBMng;
@@ -820,14 +820,14 @@ int defineTableSet(GetLongOpt& longOpt)
 	
 	Chain tsRoot(DEFAULTTSROOT);
 	
-	int sysSize = DEFAULTSYSSIZE;
-	int tmpSize = DEFAULTTMPSIZE;
-	int appSize = DEFAULTAPPSIZE;
-	int logFileSize = DEFAULTLOGSIZE;
-	int logFileNum = DEFAULTLOGNUM;
+	unsigned sysSize = DEFAULTSYSSIZE;
+	unsigned tmpSize = DEFAULTTMPSIZE;
+	unsigned appSize = DEFAULTAPPSIZE;
+	unsigned logFileSize = DEFAULTLOGSIZE;
+	unsigned logFileNum = DEFAULTLOGNUM;
 	
 	long orderSize = DEFAULTORDERSIZE;
-	int branchId = 0;
+	unsigned branchId = 0;
 	
 	Tokenizer atok(tsDef, Chain(","));
 	
@@ -841,26 +841,26 @@ int defineTableSet(GetLongOpt& longOpt)
 	    vtok.nextToken(value);
 
 	    if ( attr == Chain("syssize"))
-		sysSize = value.asInteger();
+		sysSize = value.asUnsigned();
 	    else if ( attr == Chain("tmpsize"))
-		tmpSize = value.asInteger();
+		tmpSize = value.asUnsigned();
 	    else if ( attr == Chain("appsize"))
-		appSize = value.asInteger();
+		appSize = value.asUnsigned();
 	    else if ( attr == Chain("logfilesize"))
-		logFileSize = value.asInteger();
+		logFileSize = value.asUnsigned();
 	    else if ( attr == Chain("logfilenum"))
-		logFileNum = value.asInteger();
+		logFileNum = value.asUnsigned();
 	    else if ( attr == Chain("tsroot"))
 		tsRoot = value;
 	    else if ( attr == Chain("sortareasize"))
 		orderSize = value.asLong();
 	    else if ( attr == Chain("branchid"))
-		branchId = value.asInteger();
+		branchId = value.asUnsigned();
 	}
 	
-	int sysFid = pDBMng->nextTSID();
+	unsigned sysFid = pDBMng->nextTSID();
 	
-	int tmpFid = pDBMng->nextFID();
+	unsigned tmpFid = pDBMng->nextFID();
 	
 	Chain dbHost;
 	pDBMng->getDBHost(dbHost);
@@ -913,7 +913,7 @@ int createTableSet(GetLongOpt& longOpt)
 	Chain dbXML = longOpt.getOptValue("dbxml");
 	Chain tableSet = longOpt.getOptValue("tableset");
 	Chain poolSize = longOpt.getOptValue("poolsize");
-	int numSeg, segSize;
+	unsigned numSeg, segSize;
 	getPoolInfo(poolSize, numSeg, segSize);
 
 	if ( dbXML.length() == 0  || dbXML == Chain() )
@@ -1025,7 +1025,7 @@ int importTableSet(GetLongOpt& longOpt, XPortFormat format)
 	pDBMng->initDoc();
 	pDBMng->configureLogger();
 	
-	int numSeg, segSize;
+	unsigned numSeg, segSize;
 	getPoolInfo(poolSize, numSeg, segSize);
 
 	pDBMng->initPool(numSeg, segSize);
@@ -1066,7 +1066,7 @@ int importTableSet(GetLongOpt& longOpt, XPortFormat format)
 
 	    pTabMng->startDistTableSet(tableSet, dbHost, false, true, true, false);
 
-	    int tabSetId = pDBMng->getTabSetId(tableSet);
+	    unsigned tabSetId = pDBMng->getTabSetId(tableSet);
 	    
 	    // during import we stop any log activies
 	    pDBMng->stopLog(tabSetId);
@@ -1097,7 +1097,7 @@ int importTableSet(GetLongOpt& longOpt, XPortFormat format)
 	{
 	    Chain msg;
 	    Chain module;
-	    int line;
+	    unsigned line;
 	    
 	    Chain exep;
 	    while ( e.pop(module, line, msg) )
@@ -1196,7 +1196,7 @@ int exportTableSet(GetLongOpt& longOpt, XPortFormat format)
 	pDBMng->initDoc();
 	pDBMng->configureLogger();
 
-	int numSeg, segSize;
+	unsigned numSeg, segSize;
 	getPoolInfo(poolSize, numSeg, segSize);
 	pDBMng->initPool(numSeg, segSize);
 
@@ -1263,7 +1263,7 @@ int exportTableSet(GetLongOpt& longOpt, XPortFormat format)
 	{
 	    Chain msg;
 	    Chain module;
-	    int line;
+	    unsigned line;
 	    
 	    Chain exep;
 	    while ( e.pop(module, line, msg) )
@@ -1365,7 +1365,7 @@ int runBatch(GetLongOpt& longOpt)
 	pDBMng->initDoc();
 	pDBMng->configureLogger();
 
-	int numSeg, segSize;
+	unsigned numSeg, segSize;
 	getPoolInfo(poolSize, numSeg, segSize);	
 	pDBMng->initPool(numSeg, segSize);
 
@@ -1542,7 +1542,7 @@ int runDaemon(GetLongOpt& longOpt)
 	    AESCrypt aescrypt(CEGOAESKEY, CEGOAESKEYLEN);	    
 
 	    CegoBeatConnection beat;
-	    beat = CegoBeatConnection(host, port.asInteger(), user, aescrypt.encrypt(passwd), pDBMng);
+	    beat = CegoBeatConnection(host, port.asUnsigned(), user, aescrypt.encrypt(passwd), pDBMng);
 
 	    pDBMng->xml2Doc();
 	    pDBMng->configureLogger();
@@ -1563,7 +1563,7 @@ int runDaemon(GetLongOpt& longOpt)
 
 	modId = pDBMng->getModId("CegoMain");
 
-	int numSeg, segSize;
+	unsigned numSeg, segSize;
 	getPoolInfo(poolSize, numSeg, segSize);
 	pDBMng->initPool(numSeg, segSize);
 	
@@ -1580,7 +1580,7 @@ int runDaemon(GetLongOpt& longOpt)
 	pDBMng->log(modId, Logger::DEBUG, "Creating db threadpool ...");
 #endif
 
-	pDbPool = new CegoDbThreadPool(numDbThread.asInteger(), pDBMng, protType);
+	pDbPool = new CegoDbThreadPool(numDbThread.asUnsigned(), pDBMng, protType);
 
 #ifdef CGDEBUG	
 	pDBMng->log(modId, Logger::DEBUG, "Sync db pool to ready ...");	
@@ -1596,15 +1596,15 @@ int runDaemon(GetLongOpt& longOpt)
 	pDBMng->log(modId, Logger::DEBUG, "Creating log threadpool ...");
 #endif
 
-	pLogPool = new CegoLogThreadPool(numLogThread.asInteger(), pDBMng);
+	pLogPool = new CegoLogThreadPool(numLogThread.asUnsigned(), pDBMng);
 
 #ifdef CGDEBUG		
 	pDBMng->log(modId, Logger::DEBUG, "Creating admin threadpool ...");
 #endif
 
-	pAdminPool = new CegoAdminThreadPool(numAdminThread.asInteger(), pDBMng, pDbPool, pLogPool);
+	pAdminPool = new CegoAdminThreadPool(numAdminThread.asUnsigned(), pDBMng, pDbPool, pLogPool);
 	
-	pDBMng->setThreadInfo(numDbThread.asInteger(), numAdminThread.asInteger(), numLogThread.asInteger());
+	pDBMng->setThreadInfo(numDbThread.asUnsigned(), numAdminThread.asUnsigned(), numLogThread.asUnsigned());
 		
 	pBeatThread = new CegoBeatThread(pDBMng);
 	
@@ -1700,7 +1700,7 @@ int runDaemon(GetLongOpt& longOpt)
 			pDBMng->log(modId, Logger::DEBUG, Chain("Forced loading object for ") + tableSet + Chain("..."));
 #endif
 
-			int tabSetId = pDBMng->getTabSetId(tableSet);
+			unsigned tabSetId = pDBMng->getTabSetId(tableSet);
 			pDbPool->loadObjects(tabSetId);	
 #ifdef CGDEBUG		
 			pDBMng->log(modId, Logger::DEBUG, Chain("Objects for ") + tableSet + Chain(" loaded"));
@@ -1780,7 +1780,7 @@ int runDaemon(GetLongOpt& longOpt)
 		    try 
 		    {
 			tabMng.reorgTableSet(*pAct);
-			int cpi = pDBMng->getCheckpointInterval(*pAct);
+			unsigned cpi = pDBMng->getCheckpointInterval(*pAct);
 			if ( cpc.checkpointReached(*pAct, cpi) )
 			{
 			    pDBMng->log(modId, Logger::NOTICE, Chain("Checkpoint reached for tableset ") + *pAct);
@@ -1791,7 +1791,7 @@ int runDaemon(GetLongOpt& longOpt)
 		    {
 			Chain msg;
 			Chain module;
-			int line;
+			unsigned line;
 			
 			Chain exep;
 			while ( e.pop(module, line, msg) )
@@ -1848,7 +1848,7 @@ int runDaemon(GetLongOpt& longOpt)
     {
 	Chain msg;
 	Chain module;
-	int line;
+	unsigned line;
 	
 	bool log2Console=true;
 
@@ -1917,7 +1917,6 @@ int runDaemon(GetLongOpt& longOpt)
     return exitCode;
 }
 
-
 int setQueryCache(GetLongOpt& longOpt)
 {
     int exitCode = 0;
@@ -1975,7 +1974,7 @@ int setQueryCache(GetLongOpt& longOpt)
 	if ( maxSize.length() > 0 )
 	{
 	    if ( maxSize.isNum() )
-		pDBMng->setMaxQueryCacheSize(tableSet, maxSize.asInteger());
+		pDBMng->setMaxQueryCacheSize(tableSet, maxSize.asUnsigned());
 	    else
 		throw Exception(EXLOC, "Invalid querycache maxsize");
 	}
@@ -1983,7 +1982,7 @@ int setQueryCache(GetLongOpt& longOpt)
 	if ( maxEntry.length() > 0 )
 	{
 	    if ( maxEntry.isNum() )
-		pDBMng->setMaxQueryCacheEntry(tableSet, maxEntry.asInteger());
+		pDBMng->setMaxQueryCacheEntry(tableSet, maxEntry.asUnsigned());
 	    else
 		throw Exception(EXLOC, "Invalid querycache maxentry");
 	}
@@ -1991,7 +1990,7 @@ int setQueryCache(GetLongOpt& longOpt)
 	if ( threshold.length() > 0 )
 	{
 	    if ( threshold.isNum() )
-		pDBMng->setQueryCacheThreshold(tableSet, threshold.asInteger());
+		pDBMng->setQueryCacheThreshold(tableSet, threshold.asUnsigned());
 	    else
 		throw Exception(EXLOC, "Invalid querycache threshold");
 	}
@@ -1999,7 +1998,7 @@ int setQueryCache(GetLongOpt& longOpt)
 	if ( hashRange.length() > 0 )
 	{
 	    if ( hashRange.isNum() )
-		pDBMng->setQueryCacheHashRange(tableSet, hashRange.asInteger());
+		pDBMng->setQueryCacheHashRange(tableSet, hashRange.asUnsigned());
 	    else
 		throw Exception(EXLOC, "Invalid querycache hashrange");
 	}
@@ -2022,9 +2021,7 @@ int setQueryCache(GetLongOpt& longOpt)
     return exitCode;
 }
 
-
-
-bool getPoolInfo(const Chain& poolSize, int& numSeg, int& segSize)
+bool getPoolInfo(const Chain& poolSize, unsigned& numSeg, unsigned& segSize)
 {
     Tokenizer tok(poolSize, "xX");
     Chain t1, t2;
@@ -2033,24 +2030,24 @@ bool getPoolInfo(const Chain& poolSize, int& numSeg, int& segSize)
 	if ( tok.nextToken(t2) )
 	{
 	    // multisegment spec
-	    if ( t1.asInteger() <= 0 || t2.asInteger() <= 0 )
+	    if ( t1.asUnsigned() <= 0 || t2.asUnsigned() <= 0 )
 	    {
 		return false;
 	    }
-	    numSeg=t1.asInteger();
-	    segSize=t2.asInteger();
+	    numSeg=t1.asUnsigned();
+	    segSize=t2.asUnsigned();
 	    return true;	    
 	}
 	else
 	{
-	    if ( t1.asInteger() <= 0 )
+	    if ( t1.asUnsigned() <= 0 )
 	    {
 		return false;
 	    }
 	    else
 	    {
 		numSeg=1;
-		segSize=t1.asInteger();
+		segSize=t1.asUnsigned();
 		return true;
 	    }
 	}
