@@ -34,9 +34,9 @@ public:
     CegoModule(const Chain& logFile, const Chain& progName);
     ~CegoModule();
     
-    int getModId(const Chain& module);
-    Chain getModName(int id);
-    int getMapSize();
+    unsigned getModId(const Chain& module);
+    Chain getModName(unsigned id);
+    unsigned getMapSize();
     
 private:
     
