@@ -40,7 +40,7 @@ public:
 
     virtual CegoException execute() = 0;
     virtual void cleanUp() = 0;
-    virtual Chain toChain(int defTabSetId, const Chain& indent = Chain("")) const = 0;
+    virtual Chain toChain(unsigned defTabSetId, const Chain& indent = Chain("")) const = 0;
     virtual Chain dbFormat(CegoDatabaseFormater *pForm) const = 0;
     virtual bool isStatic() const = 0;
 
