@@ -39,7 +39,7 @@ public:
     void setBlock(CegoProcBlock* pBlock);
     CegoException execute();
     void cleanUp();
-    Chain toChain(int defTabSetId, const Chain& indent = Chain("")) const;
+    Chain toChain(unsigned defTabSetId, const Chain& indent = Chain("")) const;
     Chain dbFormat(CegoDatabaseFormater *pForm) const;
     bool isStatic() const;
     
