@@ -56,7 +56,7 @@ unsigned long long CegoRecoveryManager::recoverTableSet(const Chain& tableSet, l
 	_shellCmd = Chain(pShell);
     }
     
-    int tabSetId = _pDBMng->getTabSetId(tableSet);
+    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
     
     _pDBMng->setTableSetRunState(tableSet, XML_RECOVERY_VALUE);
     _pDBMng->setRecoveryMode(tabSetId, CegoDatabaseManager::ON ); 
@@ -261,7 +261,7 @@ unsigned long long CegoRecoveryManager::recoverTableSet(const Chain& tableSet, l
     }
 }
 
-unsigned long long CegoRecoveryManager::dataFileRecovery(const Chain& tableSet, int tabSetId, unsigned long long cplsn, CegoAdminHandler* pAH)
+unsigned long long CegoRecoveryManager::dataFileRecovery(const Chain& tableSet, unsigned tabSetId, unsigned long long cplsn, CegoAdminHandler* pAH)
 {
     bool endOfBackup = false;   
     unsigned long long lsn = cplsn;
@@ -325,7 +325,7 @@ unsigned long long CegoRecoveryManager::dataFileRecovery(const Chain& tableSet,
     return lsn;
 }
 
-unsigned long long CegoRecoveryManager::transactionRecovery(const Chain& tableSet, int tabSetId, unsigned long long cplsn, long long pit, CegoAdminHandler* pAH)
+unsigned long long CegoRecoveryManager::transactionRecovery(const Chain& tableSet, unsigned tabSetId, unsigned long long cplsn, long long pit, CegoAdminHandler* pAH)
 {
     bool endOfRecovery = false;    
     Chain sourceFileName;
@@ -448,7 +448,7 @@ unsigned long long CegoRecoveryManager::transactionRecovery(const Chain& tableSe
     return lsn;
 }
 
-int CegoRecoveryManager::recoverCurrentDataFileLog(int tabSetId, bool& endOfBackup)
+unsigned long long CegoRecoveryManager::recoverCurrentDataFileLog(unsigned tabSetId, bool& endOfBackup)
 {
     unsigned long long lsn=0;
 
@@ -521,7 +521,7 @@ int CegoRecoveryManager::recoverCurrentDataFileLog(int tabSetId, bool& endOfBack
     return lsn;
 }
 
-CegoRecoveryManager::RecoveryState CegoRecoveryManager::recoverCurrentTransactionLog(int tabSetId, long long pit, unsigned long long& lsn, long long& ts)
+CegoRecoveryManager::RecoveryState CegoRecoveryManager::recoverCurrentTransactionLog(unsigned tabSetId, long long pit, unsigned long long& lsn, long long& ts)
 {
     _invalidatedList.Empty();
 
@@ -789,10 +789,10 @@ CegoRecoveryManager::RecoveryState CegoRecoveryManager::recoverCurrentTransactio
 		    unsigned long long tastep;
 		    CegoTupleState ts;
 		    
-		    int toff = CegoQueryHelper::decodeTupleHeader(tid, tastep, ts, logRec.getData());
+		    unsigned toff = CegoQueryHelper::decodeTupleHeader(tid, tastep, ts, logRec.getData());
 		    
 		    char* tp =  logRec.getData() + toff;
-		    int tlen = logRec.getDataLen() - toff;
+		    unsigned tlen = logRec.getDataLen() - toff;
 
 		    CegoQueryHelper::decodeFVL(fvl, blobList, clobList, tp, tlen);
 
@@ -981,7 +981,7 @@ bool CegoRecoveryManager::restoreLogFile(const Chain& tableSet, unsigned long ls
 	ListT<Chain> archIdList;
 	ListT<Chain> archPathList;
 	
-	int tabSetId = _pDBMng->getTabSetId(tableSet);    
+	unsigned tabSetId = _pDBMng->getTabSetId(tableSet);    
 	_pDBMng->getArchLogInfo(tabSetId, archIdList, archPathList);
 
 	_pDBMng->log(_modId, Logger::NOTICE, Chain("Waiting for logfile ") + archLogFileName + Chain(" ..."));
@@ -998,7 +998,7 @@ bool CegoRecoveryManager::restoreLogFile(const Chain& tableSet, unsigned long ls
 	
 	CommandExecuter cmdExe(_shellCmd);
 	
-	int archRestoreTimeout = _pDBMng->getArchRestoreTimeout();
+	unsigned archRestoreTimeout = _pDBMng->getArchRestoreTimeout();
 	
 	Chain restoreCmd = archRestoreProg + Chain(" -m recover -t ") + tableSet + Chain(" -f ") + archLogFileName + Chain(" -p ") + pathString;
 	
@@ -1014,7 +1014,7 @@ bool CegoRecoveryManager::restoreLogFile(const Chain& tableSet, unsigned long ls
 	{
 	    fileProvided = false;
 	}
-	else // ( retCode > 1 )
+	else
 	{
 	    Chain msg("External log manager failed");
 	    throw Exception(EXLOC, msg);			    
