@@ -130,7 +130,7 @@ Chain CegoTypeConverter::getTypeString(CegoDataType type)
     }
 }
 
-int CegoTypeConverter::getTypeLen(CegoDataType type, const Chain& val)
+unsigned CegoTypeConverter::getTypeLen(CegoDataType type, const Chain& val)
 {
     switch  ( type ) 
     {
